@@ -49,19 +49,19 @@
 		ELSE = 41,
 		WHERE = 42,
 		ELSEWHERE = 43,
-		PRINT = 44,
-		VAR_ID = 45,
-		ATT_ID = 46,
-		LCURL = 47,
-		RCURL = 48,
-		FOR = 49,
-		COLON = 50,
-		LSQUARE = 51,
-		DIM_ID = 52,
-		RSQUARE = 53,
-		DIVIDE = 54,
-		DIM_MTD_ID = 55,
-		CALL_REF = 56,
+		LCURL = 44,
+		RCURL = 45,
+		FOR = 46,
+		COLON = 47,
+		LSQUARE = 48,
+		VAR_ID = 49,
+		DIM_ID = 50,
+		RSQUARE = 51,
+		DIVIDE = 52,
+		DIM_MTD_ID = 53,
+		ATT_ID = 54,
+		CALL_REF = 55,
+		TIMES = 56,
 		DOT = 57,
 		FUNC = 58,
 		INC = 59,
@@ -69,55 +69,55 @@
 		LNOT = 61,
 		PLUS = 62,
 		MINUS = 63,
-		TIMES = 64,
-		CARET = 65,
-		MOD = 66,
-		FLTHAN = 67,
-		FGTHAN = 68,
-		LTHAN = 69,
-		GTHAN = 70,
-		GEQ = 71,
-		LEQ = 72,
-		EQ = 73,
-		NEQ = 74,
-		LAND = 75,
-		LOR = 76,
-		QUESTION = 77,
-		ASSIGN = 78,
-		PLUS_ASSIGN = 79,
-		MINUS_ASSIGN = 80,
-		TIMES_ASSIGN = 81,
-		DIVIDE_ASSIGN = 82,
-		NCAP_FLOAT = 83,
-		NCAP_DOUBLE = 84,
-		NCAP_INT = 85,
-		NCAP_BYTE = 86,
-		NCAP_UBYTE = 87,
-		NCAP_SHORT = 88,
-		NCAP_USHORT = 89,
-		NCAP_UINT = 90,
-		NCAP_INT64 = 91,
-		NCAP_UINT64 = 92,
-		N4STRING = 93,
-		DIM_ID_SIZE = 94,
-		NRootAST = 95,
-		SHIFTL = 96,
-		SHIFTR = 97,
-		QUOTE = 98,
-		DGT = 99,
-		LPH = 100,
-		LPHDGT = 101,
-		XPN = 102,
-		VAR_NM_QT = 103,
-		BLASTOUT = 104,
-		UNUSED_OPS = 105,
-		WS = 106,
-		CXX_COMMENT = 107,
-		C_COMMENT = 108,
-		NUMBER_DOT = 109,
-		NUMBER = 110,
-		VAR_ATT = 111,
-		VAR_ATT_QT = 112,
+		CARET = 64,
+		MOD = 65,
+		FLTHAN = 66,
+		FGTHAN = 67,
+		LTHAN = 68,
+		GTHAN = 69,
+		GEQ = 70,
+		LEQ = 71,
+		EQ = 72,
+		NEQ = 73,
+		LAND = 74,
+		LOR = 75,
+		QUESTION = 76,
+		ASSIGN = 77,
+		PLUS_ASSIGN = 78,
+		MINUS_ASSIGN = 79,
+		TIMES_ASSIGN = 80,
+		DIVIDE_ASSIGN = 81,
+		NCAP_FLOAT = 82,
+		NCAP_DOUBLE = 83,
+		NCAP_INT = 84,
+		NCAP_BYTE = 85,
+		NCAP_UBYTE = 86,
+		NCAP_SHORT = 87,
+		NCAP_USHORT = 88,
+		NCAP_UINT = 89,
+		NCAP_INT64 = 90,
+		NCAP_UINT64 = 91,
+		N4STRING = 92,
+		DIM_ID_SIZE = 93,
+		NRootAST = 94,
+		SHIFTL = 95,
+		SHIFTR = 96,
+		QUOTE = 97,
+		DGT = 98,
+		LPH = 99,
+		LPHDGT = 100,
+		XPN = 101,
+		VAR_NM_QT = 102,
+		BLASTOUT = 103,
+		UNUSED_OPS = 104,
+		WS = 105,
+		CXX_COMMENT = 106,
+		C_COMMENT = 107,
+		NUMBER_DOT = 108,
+		NUMBER = 109,
+		VAR_ATT = 110,
+		VAR_ATT_QT = 111,
+		STR_ATT_QT = 112,
 		DIM_QT = 113,
 		DIM_VAL = 114,
 		INCLUDE = 115,
