@@ -169,6 +169,13 @@ extern "C" {
   /* Argument to strtol() and strtoul() indicating base-10 conversions */
 #define NCO_SNG_CNV_BASE10 10
 
+  /* 20161121 Chunk cache size default
+     http://www.unidata.ucar.edu/software/netcdf/docs/netcdf_perf_chunking.html
+     netCDF cache size default settable at netCDF build time with --with-chunk-cache-size option
+     If NCO default == 0, then NCO will use whatever default built-into netCDF library
+     If NCO default  > 0, then NCO will override netCDF default */
+#define NCO_CNK_CSH_BYT_DFL 0
+
   /* netCDF 4.3.2 (201404) implements a configure-time constant called DEFAULT_CHUNK_SIZE = 4194304 = 4 MB
      This is a good size for HPC systems with MB-scale blocksizes
      Token is not in netcdf.h, and NCO's equivalent need not match netCDF's
@@ -329,7 +336,7 @@ extern "C" {
 # define NCO_VERSION_MINOR 6
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 2
+# define NCO_VERSION_PATCH 3
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE "" /* Blank for final versions, non-blank (e.g., "beta37") for pre-release versions */
@@ -339,7 +346,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "4.6.2"
+# define NCO_VERSION "4.6.3"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -788,7 +795,7 @@ extern "C" {
 
     double max_val; /* Double precision representation of maximum value of coordinate requested or implied */
     double min_val; /* Double precision representation of minimum value of coordinate requested or implied */
-    double origin;   /* Used by ncra, ncrcat to re-base record coordinate */
+    double origin; /* Used by ncra, ncrcat to re-base record coordinate */
 
     int id; /* Dimension ID */
     int lmt_typ; /* crd_val or dmn_idx */
@@ -948,6 +955,7 @@ extern "C" {
     nco_bool nwl_pst_val; /* [flg] Print newline after variable values */
     int fll_pth; /* [nbr] Print full paths */
     int jsn_att_fmt; /* [enm] JSON format for netCDF attributes: 0 (no object, only data), 1 (data only for string, char, int, and floating-point types, otherwise object), 2 (always object) */ 
+    int jsn_data_brk; /* [flg] JSON format for netCDF variables: 0 (no bracketing of var data ), 1 ( bracketing of var data )*/
     int nbr_zro; /* [nbr] Trailing zeros allowed after decimal point */
     int ndn; /* [nbr] Indentation */
     int spc_per_lvl; /* [nbr] Indentation spaces per group level */
@@ -1171,6 +1179,7 @@ extern "C" {
     cnk_dmn_sct **cnk_dmn; /* [sct] User-specified per-dimension chunking information */
     int cnk_map; /* [enm] Chunking map */
     int cnk_plc; /* [enm] Chunking policy */
+    size_t cnk_csh_byt; /* [B] Chunk cache size */
     size_t cnk_min_byt; /* [B] Minimize size of variable to chunk */
     size_t cnk_sz_byt; /* [B] Chunk size in Bytes */
     size_t cnk_sz_scl; /* [nbr] Chunk size scalar */
