@@ -18,6 +18,7 @@
 #endif /* !HAVE_CONFIG_H */
 
 /* Standard header files */
+#include <math.h> /* sin cos cos sin 3.14159 isfinite isinf isnan */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
 #include <string.h> /* strcmp() */
 #ifdef HAVE_STRINGS_H
@@ -35,6 +36,7 @@
 #include "nco_ctl.h" /* Program flow control functions */
 #include "nco_lst_utl.h" /* List utilities */
 #include "nco_mmr.h" /* Memory management */
+#include "nco_mta.h" /* Multi-argument parsing */
 #include "nco_mss_val.h" /* Missing value utilities */
 #ifdef _MSC_VER
 # include "nco_rth_flt.h" /* Float-precision arithmetic, MSVC macros */
@@ -52,7 +54,7 @@ nco_aed_prc_wrp /* [fnc] Expand regular expressions then pass attribute edits to
  const int var_id, /* I [id] ID of variable on which to perform attribute editing */
  const aed_sct aed); /* I [sct] Attribute-edit information */
 
-  nco_bool /* [flg] Attribute was altered */
+nco_bool /* [flg] Attribute was altered */
 nco_aed_prc /* [fnc] Process single attribute edit for single variable */
 (const int nc_id, /* I [id] Input netCDF file ID */
  const int var_id, /* I [id] ID of variable on which to perform attribute editing */
@@ -74,6 +76,7 @@ nco_bool /* [flg] Attribute was changed */
 nco_aed_prc_var_all /* [fnc] Process attributes in all variables */
 (const int nc_id, /* I [id] netCDF file ID */
  const aed_sct aed, /* I [sct] Attribute-edit information */
+ const nco_bool flg_typ_mch, /* I [flg] Type-match attribute edits */
  const trv_tbl_sct * const trv_tbl); /* I [lst] Traversal table */ 
 
 nco_bool /* [flg] Attribute was changed */
