@@ -1,6 +1,6 @@
 /* $Header$ */
 
-/* Purpose: Binary write utilities */
+/* Purpose: Binary file utilities */
 
 /* Copyright (C) 1995--2016 Charlie Zender
    This file is part of NCO, the netCDF Operators. NCO is free software.
@@ -8,7 +8,7 @@
    GNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file */
 
 /* Usage:
-   #include "nco_bnr.h" *//* Binary write utilities */
+   #include "nco_bnr.h" *//* Binary file utilities */
 
 #ifndef NCO_BNR_H
 #define NCO_BNR_H
@@ -28,9 +28,10 @@
 extern "C" {
 #endif /* __cplusplus */
 
-FILE * /* O [fl] Unformatted binary output file handle */
-nco_bnr_open /* [fnc] Open unformatted binary data file for writing */
-(const char * const fl_bnr); /* [sng] Unformatted binary output file */
+FILE * /* O [fl] Unformatted binary file handle */
+nco_bnr_open /* [fnc] Open unformatted binary data file */
+(const char * const fl_bnr, /* [sng] Unformatted binary file */
+ const char * const fl_mode); /* [sng] Open-mode ("r", "w", ...) */
 
 int /* [rcd] Return code */
 nco_bnr_close /* [fnc] Close unformatted binary data file for writing */
@@ -45,6 +46,14 @@ nco_bnr_wrt /* [fnc] Write unformatted binary data */
  const nc_type var_typ, /* I [enm] Variable type */
  const void * const void_ptr); /* I [ptr] Data to write */
 
+size_t /* O [nbr] Number of elements successfully read */
+nco_bnr_rd /* [fnc] Read unformatted binary data */
+(FILE * const fp_bnr, /* I [fl] Unformatted binary input file handle */
+ const char * const var_nm, /* I [sng] Variable name */
+ const long var_sz, /* I [nbr] Variable size */
+ const nc_type var_typ, /* I [enm] Variable type */
+ void * const void_ptr); /* O [ptr] Data to read */
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
