@@ -132,291 +132,6 @@ nco_newdate /* [fnc] Compute date a specified number of days from input date */
   return newdate_YYMMDD;
 } /* end nco_newdate() */
 
-#ifdef ENABLE_UDUNITS
-# ifdef HAVE_UDUNITS2_H
-
-/* UDUnits2 routines */
-
-int /* [rcd] Return code */
-nco_cln_clc_dff /* [fnc] UDUnits2 Compute difference between two coordinate units */
-(const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
- const char *fl_bs_sng, /* I [ptr] units attribute string from disk */
- double crr_val,
- double *og_val) /* O [] Difference between two units strings */
-{
-  const char fnc_nm[]="nco_cln_clc_dff()"; /* [sng] Function name */
-  
-  cv_converter *ut_cnv; /* UDUnits converter */
-
-  int ut_rcd; /* [enm] UDUnits2 status */
-  
-  ut_system *ut_sys;
-  ut_unit *ut_sct_in; /* [sct] UDUnits structure, input units */
-  ut_unit *ut_sct_out; /* [sct] UDUnits structure, output units */
-  
-  /* Quick return if units identical */
-  if(!strcasecmp(fl_unt_sng,fl_bs_sng)){
-    *og_val=crr_val;  
-    return NCO_NOERR;
-  } /* end if */
-  
-  /* When empty, ut_read_xml() uses environment variable UDUNITS2_XML_PATH, if any
-     Otherwise it uses default initial location hardcoded when library was built */
-  if(nco_dbg_lvl_get() >= nco_dbg_vrb) ut_set_error_message_handler(ut_write_to_stderr); else ut_set_error_message_handler(ut_ignore);
-  ut_sys=ut_read_xml(NULL);
-  if(ut_sys == NULL){
-    (void)fprintf(stdout,"%s: %s() failed to initialize UDUnits2 library\n",nco_prg_nm_get(),fnc_nm);
-    return NCO_ERR; /* Failure */
-  } /* end if err */ 
-  
-  /* Units string to convert from */
-  ut_sct_in=ut_parse(ut_sys,fl_unt_sng,UT_ASCII); 
-  if(!ut_sct_in){ /* Problem with 'units' attribute */
-    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
-    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: empty units attribute string\n");
-    if(ut_rcd == UT_SYNTAX) (void)fprintf(stderr,"ERROR: units attribute \"%s\" has a syntax error\n",fl_unt_sng);
-    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",fl_unt_sng);
-    return NCO_ERR; /* Failure */
-  } /* endif coordinate on disk has no units attribute */
-
-  /* Units string to convert to */
-  ut_sct_out=ut_parse(ut_sys,fl_bs_sng,UT_ASCII); 
-  if(!ut_sct_out){ /* Problem with 'units' attribute */
-    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
-    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: Empty units attribute string\n");
-    if(ut_rcd == UT_SYNTAX) (void)fprintf(stderr,"ERROR: units attribute  \"%s\" has a syntax error\n",fl_bs_sng);
-    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",fl_bs_sng);
-    return NCO_ERR; /* Failure */
-  } /* endif */
-
-  /* Create converter */
-  ut_cnv=ut_get_converter(ut_sct_in,ut_sct_out); /* UDUnits converter */
-  if(!ut_cnv){
-    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
-    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"WARNING: One of units, %s or %s, is NULL\n",fl_bs_sng,fl_unt_sng);
-    if(ut_rcd == UT_NOT_SAME_SYSTEM) (void)fprintf(stderr,"WARNING: Units %s and %s belong to different unit systems\n",fl_bs_sng,fl_unt_sng);
-    if(ut_rcd == UT_MEANINGLESS) (void)fprintf(stderr,"WARNING: Conversion between user-specified unit \"%s\" and file units \"%s\" is meaningless\n",fl_bs_sng,fl_unt_sng);
-    return NCO_ERR; /* Failure */
-  } /* endif */
-
-  /* Convert */
-  *og_val=cv_convert_double(ut_cnv,crr_val);
-  
-  if(nco_dbg_lvl_get() >= nco_dbg_var) fprintf(stderr, "%s: INFO %s() reports conversion between systems \"%s\" and \"%s\" is %f\n",nco_prg_nm_get(),fnc_nm,fl_unt_sng,fl_bs_sng,*og_val);
-
-  ut_free(ut_sct_in);
-  ut_free(ut_sct_out);
-  cv_free(ut_cnv);
-  ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
-
-  return NCO_NOERR;
-}  /* end UDUnits2 nco_cln_clc_dff() */
-
-int /* [rcd] Successful conversion returns NCO_NOERR */
-nco_cln_prs_tm /* UDUnits2 Extract time stamp from parsed UDUnits string */
-(const char *unt_sng, /* I [ptr] units attribute string */
- tm_cln_sct *tm_in) /* O [sct] Time structure to be populated */
-{
-  const char fnc_nm[]="nco_cln_prs_tm()"; /* [sng] Function name */
-
-  /* 20141230: fxm figure out a better length */
-  char bfr[200];
-
-  char *dt_sng;
-
-  int ut_rcd; /* [enm] UDUnits2 status */
-
-  ut_system *ut_sys;
-  ut_unit *ut_sct_in; /* UDUnits structure, input units */
-
-  /* When empty, ut_read_xml() uses environment variable UDUNITS2_XML_PATH, if any
-     Otherwise it uses default initial location hardcoded when library was built */
-  if(nco_dbg_lvl_get() >= nco_dbg_vrb) ut_set_error_message_handler(ut_write_to_stderr); else ut_set_error_message_handler(ut_ignore);
-  ut_sys=ut_read_xml(NULL);
-  if(ut_sys == NULL){
-    (void)fprintf(stdout,"%s: %s failed to initialize UDUnits2 library\n",nco_prg_nm_get(),fnc_nm);
-    return NCO_ERR; /* Failure */
-  } /* end if err */ 
-
-  /* Units string to convert from */
-  ut_sct_in=ut_parse(ut_sys,unt_sng,UT_ASCII); 
-  if(ut_sct_in == NULL){ /* Problem with 'units' attribute */
-    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
-    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: empty units attribute string\n");
-    if(ut_rcd == UT_SYNTAX)  (void)fprintf(stderr,"ERROR: units attribute \"%s\" has a syntax error\n",unt_sng);
-    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",unt_sng);
-
-    return NCO_ERR; /* Failure */
-  } /* endif coordinate on disk has no units attribute */
-
-  /* Print timestamp to buffer in standard, dependable format */
-  ut_format(ut_sct_in,bfr,sizeof(bfr),UT_ASCII|UT_NAMES);
-
-  /* Extract parsed time units from print string (kludgy)
-     20141230 change to using ut_decode_time() instead? */
-  dt_sng=strstr(bfr,"since");  
-  sscanf(dt_sng,"%*s %d-%d-%d %d:%d:%f",&tm_in->year,&tm_in->month,&tm_in->day,&tm_in->hour,&tm_in->min,&tm_in->sec);
-
-  ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
-  ut_free(ut_sct_in);
-
-  return NCO_NOERR;
-} /* end UDUnits2 nco_cln_prs_tm() */
-
-# else /* !HAVE_UDUNITS2_H */
-
-/* UDUnits1 routines */
-
-int /* [rcd] Successful conversion returns NCO_NOERR */
-nco_cln_clc_dff /* [fnc] UDUnits1 Difference between two co-ordinate units */
-(const char *fl_unt_sng, /* I [ptr] units attribute string from disk  */     
- const char *fl_bs_sng, /* I [ptr] units attribute string from disk  */     
- double crr_val,
- double *og_val) /* O [ptr] */
-{
-  const char fnc_nm[]="nco_cln_clc_dff()"; /* [sng] Function name */
-    
-  double slp;
-  double incpt;
-
-  int rcd;
-
-  utUnit udu_sct_in; /* UDUnits structure, input units */
-  utUnit udu_sct_out; /* UDUnits structure, output units */
-
-  /* Quick return if units identical */
-  if(!strcmp(fl_unt_sng,fl_bs_sng) ){
-    *og_val=crr_val;  
-    return NCO_NOERR;
-  } /* endif */
-
-#ifdef UDUNITS_PATH
-  /* UDUNITS_PATH macro expands to where autoconf found database file */
-  rcd=utInit(UDUNITS_PATH);
-#else /* !UDUNITS_PATH */
-  /* When empty, utInit() uses environment variable UDUNITS_PATH, if any
-     Otherwise it uses default initial location hardcoded when library was built */
-  rcd=utInit("");
-#endif /* !UDUNITS_PATH */
-
-  if(rcd != UDUNITS_NOERR){
-    (void)fprintf(stdout,"%s: %s failed to initialize UDUnits2 library\n",nco_prg_nm_get(),fnc_nm);
-    return NCO_ERR;
-  } /* end if err */ 
-
-  /* units string to convert from */
-  rcd=utScan(fl_unt_sng,&udu_sct_in); 
-  if(rcd != UDUNITS_NOERR){
-    if(rcd == UT_EINVALID) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is invalid \n",fl_unt_sng);
-    if(rcd == UT_ESYNTAX) (void)fprintf(stderr,"ERROR units attribute \"%s\" contains a syntax error",fl_unt_sng);
-    if(rcd == UT_EUNKNOWN) (void)fprintf(stderr,"ERROR units attribute \"%s\" is not in udunits database",fl_unt_sng);
-    (void)utTerm(); /* Free memory taken by UDUnits library */
-    return NCO_ERR;
-  } /* endif unkown type */
-
-  /* units string to convert to */
-  rcd=utScan(fl_bs_sng,&udu_sct_out); 
-  if(rcd != UDUNITS_NOERR){
-    if(rcd == UT_EINVALID) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is invalid \n",fl_bs_sng);
-    if(rcd == UT_ESYNTAX) (void)fprintf(stderr,"ERROR units attribute \"%s\" contains a syntax error",fl_bs_sng);
-    if(rcd == UT_EUNKNOWN) (void)fprintf(stderr,"ERROR units attribute \"%s\" is not in udunits database",fl_bs_sng);
-    (void)utTerm(); /* Free memory taken by UDUnits library */
-    return NCO_ERR;
-  } /* endif unkown type */
-
-  rcd=utConvert(&udu_sct_in,&udu_sct_out,&slp,&incpt);
-  if(rcd == UT_ECONVERT){
-    (void)fprintf(stderr,"ERROR: user specified unit \"%s\" cannot be converted to units \"%s\"\n",fl_unt_sng,fl_bs_sng);
-    (void)utTerm();
-    return NCO_ERR;
-  } /* endif */
-
-  *og_val=crr_val*slp+incpt;
-
-  /* debug stuff */
-  if(nco_dbg_lvl_get() > nco_dbg_std) (void)fprintf(stderr,"%s: %s reports difference between systems \"%s\" and \"%s\" is %f\n",nco_prg_nm_get(),fnc_nm,fl_unt_sng,fl_bs_sng,*og_val);
-
-  (void)utTerm();
-
-  return NCO_NOERR;   
-}  /* end UDUnits1 nco_cln_clc_dff() */
-
-int /* [rcd] Successful conversion returns NCO_NOERR */
-nco_cln_prs_tm /* UDUnits1 Extract time stamp from a parsed udunits string */
-(const char *unt_sng, /* I [ptr] units attribute string */
- tm_cln_sct *tm_in) /* O [sct] Time structure to be populated */
-{
-  const char fnc_nm[]="nco_cln_prs_tm()"; /* [sng] Function name */
-
-  int rcd;
-
-  utUnit udu_sct_in; /* UDUnits structure, input units */
-
-#ifdef UDUNITS_PATH
-  /* UDUNITS_PATH macro expands to where autoconf found database file */
-  rcd=utInit(UDUNITS_PATH);
-#else /* !UDUNITS_PATH */
-  /* When empty, utInit() uses environment variable UDUNITS_PATH, if any
-     Otherwise it uses default initial location hardcoded when library was built */
-  rcd=utInit("");
-#endif /* !UDUNITS_PATH */
-
-  if(rcd != UDUNITS_NOERR){
-    (void)fprintf(stdout,"%s: %s failed to initialize UDUnits library\n",nco_prg_nm_get(),fnc_nm);
-    return NCO_ERR;
-  } /* end if err */ 
-
-  /* Units string to convert from */
-  rcd=utScan(unt_sng,&udu_sct_in); 
-  if(rcd != UDUNITS_NOERR){
-    if(rcd == UT_EINVALID) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is invalid \n",unt_sng);
-    if(rcd == UT_ESYNTAX) (void)fprintf(stderr,"ERROR units attribute \"%s\" contains a syntax error",unt_sng);
-    if(rcd == UT_EUNKNOWN) (void)fprintf(stderr,"ERROR units attribute \"%s\" is not in udunits database",unt_sng);
-    (void)utTerm(); /* Free memory taken by UDUnits library */
-    return NCO_ERR;
-  } /* endif unkown type */
-
-  /* Extract time origin */
-  if(utIsTime(&udu_sct_in)){
-    utCalendar(0.0,&udu_sct_in,&tm_in->year,&tm_in->month,&tm_in->day,&tm_in->hour,&tm_in->min,&tm_in->sec);
-    rcd=NCO_NOERR;  
-  }else{
-    rcd=NCO_ERR;
-  } /* endelse */
-
- (void)utTerm(); /* Free memory taken by UDUnits library */
- return rcd;
-
-} /* end UDUnits1 nco_cln_prs_tm() */
-
-# endif /* !HAVE_UDUNITS2 */
-
-#else /* !ENABLE_UDUNITS */
-
-/* No UDUnits implementation available */
-
-/* Stubs to enable compilation without UDUnits */
-
-int /* [rcd] Successful conversion returns NCO_NOERR */
-nco_cln_clc_dff( /* [fnc] Difference between two co-ordinate units */      
-const char *fl_unt_sng, /* I [ptr] units attribute string from disk  */     
-const char *fl_bs_sng, /* I [ptr] units attribute string from disk  */     
-double crr_val,
-double *og_val){ /* O [ptr] */
-  return NCO_NOERR;
-}
-
-int /* [rcd] Successful conversion returns NCO_NOERR */     
-nco_cln_prs_tm( /* Extract time stamp from a parsed UDUnits string */
-const char *unt_sng, /* I [ptr] units attribute string */
-tm_cln_sct *tm_in){ /* O [sct] struct to be populated */             
-  return NCO_NOERR;
-}
-
-#endif /* !ENABLE_UDUNITS */
-
-/* End UDUnits-related routines*/
- 
 tm_typ /* O [enm] Units type */
 nco_cln_get_tm_typ /* Returns time unit type or tm_void if not found */
 (const char *ud_sng){ /* I [ptr] Units string  */
@@ -548,10 +263,9 @@ nco_cln_pop_val /* [fnc] Calculate value in cln_sct */
   return;
 } /* end nco_cln_pop_val() */
 
-double /* O [dbl] relative time */
-nco_cln_rel_val
-(double offset, /* I [dbl] time in base units */
- nco_cln_typ lmt_cln, /* I [enm] Calendar type */ 
+double /* O [dbl] time in (base) seconds of tm_typ */
+nco_cln_val_tm_typ
+( nco_cln_typ lmt_cln, /* I [enm] Calendar type */ 
  tm_typ bs_tm_typ) /* I [enm] Time units */
 {
   double *data=NULL_CEWI;
@@ -596,102 +310,9 @@ nco_cln_rel_val
     break;     
   } /* end switch */ 
   
-  return offset/scl;
-} /* end nco_cln_rel_val() */
+  return scl;
+} /* end nco_cln_typ_val() */
 
-int /* [rcd] Successful conversion returns NCO_NOERR */
-nco_cln_clc_tm /* [fnc] Difference between two coordinate units */
-(const char *fl_unt_sng, /* I [ptr] Units attribute string from disk */
- const char *fl_bs_sng, /* I [ptr] Units attribute string from disk */
- nco_cln_typ lmt_cln, /* [enum] Calendar type of coordinate variable */ 
- double *og_val){ /* O [ptr] */
-  
-  int rcd;
-  int year;
-  int month;
-  char *lcl_unt_sng;
-  /* 20141230 figure out better length */
-  char tmp_sng[100];
-  double crr_val;
-  
-  tm_typ bs_tm_typ; /* enum for units type in fl_bs_sng */
-  tm_cln_sct unt_cln_sct;
-  tm_cln_sct bs_cln_sct;
-  
-  if(nco_dbg_lvl_get() >= nco_dbg_scl) (void)fprintf(stderr,"%s: nco_cln_clc_tm() reports unt_sng=%s bs_sng=%s\n",nco_prg_nm_get(),fl_unt_sng,fl_bs_sng);
-  
-  /* Does fl_unt_sng look like a regular timestamp? */ 
-  if(sscanf(fl_unt_sng,"%d-%d",&year,&month) == 2){
-    lcl_unt_sng=(char *)nco_malloc((strlen(fl_unt_sng)+3L)*sizeof(char));
-    strcpy(lcl_unt_sng,"s@");
-    strcat(lcl_unt_sng,fl_unt_sng);
-  }else{
-    lcl_unt_sng=strdup(fl_unt_sng);
-  } /* endelse */
-  
-  /* Temporary until we handle more calendar types */
-  if(lmt_cln != cln_360 && lmt_cln != cln_365){
-    rcd=nco_cln_clc_dff(lcl_unt_sng,fl_bs_sng,0.0,og_val);
-    lcl_unt_sng=(char *)nco_free(lcl_unt_sng);
-    return rcd;
-  } /* endif */
-
-  /* Obtain units type from fl_bs_sng */
-  if(sscanf(fl_bs_sng,"%s",tmp_sng) != 1) return NCO_ERR;
-  
-  bs_tm_typ=nco_cln_get_tm_typ(tmp_sng);  
-  
-  /* Assume non-standard calendar */ 
-  if(nco_cln_prs_tm(lcl_unt_sng,&unt_cln_sct) == NCO_ERR) return NCO_ERR;
-  if(nco_cln_prs_tm(fl_bs_sng,&bs_cln_sct) == NCO_ERR) return NCO_ERR;
-  
-  unt_cln_sct.sc_typ=bs_tm_typ;
-  bs_cln_sct.sc_typ=bs_tm_typ;
-  
-  unt_cln_sct.sc_cln=lmt_cln;
-  bs_cln_sct.sc_cln=lmt_cln;
-  
-  (void)nco_cln_pop_val(&unt_cln_sct);
-  (void)nco_cln_pop_val(&bs_cln_sct);
-  
-  crr_val=nco_cln_rel_val(unt_cln_sct.value-bs_cln_sct.value,lmt_cln,bs_tm_typ);                 
-  
-  *og_val=crr_val;
-  
-  lcl_unt_sng=(char *)nco_free(lcl_unt_sng);
-  
-  return NCO_NOERR;
-} /* end nco_cln_clc_tm() */
-
-int /* [rcd] Successful conversion returns NCO_NOERR */
-nco_cln_clc_org /* [fnc] Difference between two generic co-ordinate units */
-(const char *fl_unt_sng, /* I [ptr] Source value (optional) and source units */
- const char *fl_bs_sng, /* I [ptr] Target units */
- nco_cln_typ lmt_cln, /* [enm] Calendar type, if any, of coordinate variable */ 
- double *og_val) /* O [ptr] Target value in units stored on disk */
-{
-  /* Purpose:
-     Given a value expressed source units (fl_unit_sng) and target units to switch to, 
-     determine and return the value expressed in the target units. */
-
-  int rcd;
-  
-  char *usr_unt_sng;   
-  double crr_val;
-  
-  /* If units contain date or timestamp call special time-conversion routine */
-  if(strcasestr(fl_bs_sng," from ") || strcasestr(fl_bs_sng," since ") || strcasestr(fl_bs_sng," after ")){
-    rcd=nco_cln_clc_tm(fl_unt_sng,fl_bs_sng,lmt_cln,og_val);   
-    return rcd;
-  } /* endif */
-  
-  /* Regular conversion of fl_unt_sng of form <double_value units>, e.g., '10 inches', '100 ft' */
-  usr_unt_sng=(char *)nco_calloc(strlen(fl_unt_sng)+1L, sizeof(char));
-  sscanf(fl_unt_sng,"%lg %s",&crr_val,usr_unt_sng);
-  rcd=nco_cln_clc_dff(usr_unt_sng,fl_bs_sng,crr_val,og_val);
-  usr_unt_sng=(char *)nco_free(usr_unt_sng);
-  return rcd;  
-} /* end nco_cln_clc_org() */
 
 int /* O [flg] String is calendar date */
 nco_cln_chk_tm /* [fnc] Is string a UDUnits-compatible calendar format, e.g., "PERIOD since REFERENCE_DATE" */
@@ -705,6 +326,501 @@ nco_cln_chk_tm /* [fnc] Is string a UDUnits-compatible calendar format, e.g., "P
 
 } /* end nco_cln_chk_tm() */
 
+#ifndef ENABLE_UDUNITS
+/* Stub functions to compile without UDUNITS2 */
+
+int /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_var_dff( /* [fnc] difference between two co-ordinate units */
+const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
+double *dval,           /* I/O [dbl] var values modified */
+var_sct *var)           /* I/O [var_sct] var values modified */
+{
+  return NCO_NOERR;
+}
+
+int /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_org(   /* [fnc] difference between two co-ordinate units */
+const char *val_unt_sng, /* I [ptr] input value and  units in the same string */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
+double *og_val)         /* O [dbl] output value */
+{
+  *og_val=0.0; /* CEWI */
+  return NCO_NOERR; 
+}
+
+int /* [rcd] Return code */
+nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
+(const ptr_unn val, /* I [sct] Value to rebase */
+ const long val_idx, /* I [idx] Index into 1-D array of values */
+ const nc_type val_typ, /* I [enm] Value type */
+ const char *unit_sng, /* I [sng] Units string */
+ char *lgb_sng) /* O [sng] Legible version of input string */
+{
+  lgb_sng[0]='\0'; /* CEWI */
+  return NCO_NOERR;
+} /* end nco_cln_sng_rbs() */
+  
+#endif /* !ENABLE_UDUNITS */
+
+#ifdef ENABLE_UDUNITS
+# ifdef HAVE_UDUNITS2_H
+
+/* UDUnits2 routines */
+cv_converter*   /* UDUnits converter */
+nco_cln_cnv_mk  /* [fnc] UDUnits2 create a custom converter  */
+(const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+ const char *fl_bs_sng) /* I [ptr] units attribute string from disk */
+{
+  const char fnc_nm[]="nco_cln_cnv_mk"; /* [sng] Function name */
+  
+  cv_converter *ut_cnv; /* UDUnits converter */
+
+  int ut_rcd; /* [enm] UDUnits2 status */
+  
+  ut_system *ut_sys;
+  ut_unit *ut_sct_in; /* [sct] UDUnits structure, input units */
+  ut_unit *ut_sct_out; /* [sct] UDUnits structure, output units */
+  
+  /* When empty, ut_read_xml() uses environment variable UDUNITS2_XML_PATH, if any
+     Otherwise it uses default initial location hardcoded when library was built */
+  if(nco_dbg_lvl_get() >= nco_dbg_vrb) ut_set_error_message_handler(ut_write_to_stderr); else ut_set_error_message_handler(ut_ignore);
+  ut_sys=ut_read_xml(NULL);
+  if(ut_sys == NULL){
+    (void)fprintf(stdout,"%s: %s() failed to initialize UDUnits2 library\n",nco_prg_nm_get(),fnc_nm);
+    return (cv_converter*)NULL; /* Failure */
+  } /* end if err */ 
+  
+  /* Units string to convert from */
+  ut_sct_in=ut_parse(ut_sys,fl_unt_sng,UT_ASCII); 
+  if(!ut_sct_in){ /* Problem with 'units' attribute */
+    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
+    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: empty units attribute string\n");
+    if(ut_rcd == UT_SYNTAX) (void)fprintf(stderr,"ERROR: units attribute \"%s\" has a syntax error\n",fl_unt_sng);
+    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",fl_unt_sng);
+    return (cv_converter*)NULL; /* Failure */
+  } /* endif coordinate on disk has no units attribute */
+
+  /* Units string to convert to */
+  ut_sct_out=ut_parse(ut_sys,fl_bs_sng,UT_ASCII); 
+  if(!ut_sct_out){ /* Problem with 'units' attribute */
+    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
+    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: Empty units attribute string\n");
+    if(ut_rcd == UT_SYNTAX) (void)fprintf(stderr,"ERROR: units attribute  \"%s\" has a syntax error\n",fl_bs_sng);
+    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",fl_bs_sng);
+    return (cv_converter*)NULL; /* Failure */
+  } /* endif */
+
+  /* Create converter */
+  ut_cnv=ut_get_converter(ut_sct_in,ut_sct_out); /* UDUnits converter */
+  if(!ut_cnv){
+    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
+    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"WARNING: One of units, %s or %s, is NULL\n",fl_bs_sng,fl_unt_sng);
+    if(ut_rcd == UT_NOT_SAME_SYSTEM) (void)fprintf(stderr,"WARNING: Units %s and %s belong to different unit systems\n",fl_bs_sng,fl_unt_sng);
+    if(ut_rcd == UT_MEANINGLESS) (void)fprintf(stderr,"WARNING: Conversion between user-specified unit \"%s\" and file units \"%s\" is meaningless\n",fl_bs_sng,fl_unt_sng);
+    return (cv_converter*)NULL; /* Failure */
+  } /* endif */
+
+  ut_free(ut_sct_in);
+  ut_free(ut_sct_out);
+  ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
+  // cv_free(ut_cnv);
+
+
+  return ut_cnv;
+}  /* end UDUnits2 nco_cln_cnv_mk() */
+
+
+int    /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_dff( /* [fnc] difference between two co-ordinate units */
+const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+double *og_val)
+{           /* I/O [dbl] var values modified */
+
+  cv_converter *ut_cnv=NULL; 
+  const char fnc_nm[]="nco_cln_clc_var_dff()"; /* [sng] Function name */
+  
+  
+  /* do nothing if units identical */
+  if(strcasecmp(fl_unt_sng,fl_bs_sng)==0)
+    return NCO_NOERR;
+
+  /* Convert */
+  ut_cnv=nco_cln_cnv_mk(fl_unt_sng, fl_bs_sng);
+
+  if(ut_cnv != NULL)
+     og_val[0]=cv_convert_double(ut_cnv,og_val[0]);                      
+  else
+     return NCO_ERR;     
+
+ cv_free(ut_cnv);  
+
+ return NCO_NOERR;          
+}  
+
+
+int    /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_var_dff( /* [fnc] difference between two co-ordinate units */
+const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+var_sct *var)
+{           /* I/O [dbl] var values modified */
+
+  size_t sz;
+  size_t idx;    
+  double *dp;  
+  ptr_unn op1;    
+
+  cv_converter *ut_cnv=NULL; 
+  const char fnc_nm[]="nco_cln_clc_var_dff()"; /* [sng] Function name */
+  
+  
+  /* do nothing if units identical */
+  if(strcasecmp(fl_unt_sng,fl_bs_sng)==0)
+    return NCO_NOERR;
+
+  /* Convert */
+  ut_cnv=nco_cln_cnv_mk(fl_unt_sng, fl_bs_sng);
+
+  if(ut_cnv == NULL)
+      return NCO_ERR;     
+
+  sz=var->sz;  
+
+  (void)cast_void_nctype(var->type,&op1);                
+  op1=var->val;
+ 
+  if(var->type==NC_DOUBLE)
+  {
+
+    double *dp;
+    dp=op1.dp;     
+
+  if(var->has_mss_val)
+  {
+      double mss_dbl=var->mss_val.dp[0]; 
+      for(idx=0; idx<sz; idx++)
+	if( dp[idx] != mss_dbl)   
+	  dp[idx]=cv_convert_double(ut_cnv,dp[idx]);                      
+  }else
+     (void)cv_convert_doubles(ut_cnv,dp,sz,dp);                      
+  
+
+  }
+
+  else if(var->type==NC_FLOAT)
+  {
+
+    float*fp;
+    fp=op1.fp;     
+
+  if(var->has_mss_val)
+  {
+      float mss_fp=var->mss_val.fp[0]; 
+      for(idx=0; idx<sz; idx++)
+	if( fp[idx] != mss_fp)   
+	  fp[idx]=cv_convert_float(ut_cnv,fp[idx]);                      
+  }
+  else
+    (void)cv_convert_floats(ut_cnv,fp,sz,fp);                      
+  
+
+  }
+
+
+ cv_free(ut_cnv);  
+ (void)cast_nctype_void(var->type,&op1);
+
+ return NCO_NOERR;
+                
+}  
+
+
+int    /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_var_dff( /* [fnc] difference between two co-ordinate units */
+const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
+double *og_val,           /* I/O [dbl] var values modified -can be NULL */
+var_sct *var)           /* I/O [var_sct] var values modified - can be NULL  */
+{
+  int rcd;
+  int is_date;
+  const char fnc_nm[]="nco_cln_clc_dv_dff()"; /* [sng] Function name */
+
+  if(nco_dbg_lvl_get() >= nco_dbg_scl) 
+     (void)fprintf(stderr,"%s: nco_cln_clc_dbl_var_dff() reports unt_sng=%s bs_sng=%s calendar=%d\n",nco_prg_nm_get(),fl_unt_sng,fl_bs_sng,lmt_cln);
+
+
+  
+  /* do nothing if units identical */
+  if(!strcasecmp(fl_unt_sng,fl_bs_sng))
+    return NCO_NOERR;
+
+
+  /* see if target units is of the form  "units since date-string" */
+  is_date = nco_cln_chk_tm(fl_bs_sng);
+
+  /* use custom time functions if irregular calendar */
+  if(is_date && (lmt_cln==cln_360 || lmt_cln==cln_365) )
+    rcd=nco_cln_clc_tm( fl_unt_sng, fl_bs_sng,lmt_cln, og_val, var);  
+
+  else if(og_val != (double*)NULL) 
+     rcd=nco_cln_clc_dbl_dff(fl_unt_sng, fl_bs_sng,og_val);  
+
+  else if(var != (var_sct*)NULL)
+    rcd=nco_cln_clc_var_dff(fl_unt_sng, fl_bs_sng,var);
+
+  
+
+  return rcd;
+
+}  /* end UDUnits2 nco_cln_clc_dff() */
+
+
+
+int   /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_org(   /* [fnc] difference between two co-ordinate units */
+const char *val_unt_sng, /* I [ptr] input value and  units in the same string */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
+double *og_val)         /* O [dbl] output value */
+{
+  int is_date;  /* set to true if date/time unit */
+  int rcd;
+  int month;
+  int year;
+
+  char lcl_unt_sng[200];
+  const char fnc_nm[]="nco_cln_dbl_org"; /* [sng] Function name */
+  
+  double dval;
+
+  rcd=0;  
+
+  dval=0.0;
+
+  is_date = nco_cln_chk_tm(fl_bs_sng);
+
+  lcl_unt_sng[0]='\0';
+  
+  if(nco_dbg_lvl_get() >= nco_dbg_vrb) 
+       (void)fprintf(stderr,"%s: INFO %s: reports unt_sng=%s bs_sng=%s calendar=%d\n",nco_prg_nm_get(),fnc_nm,val_unt_sng,fl_bs_sng,lmt_cln);
+
+  
+    /* Does fl_unt_sng look like a regular timestamp? */ 
+  if(is_date && sscanf(val_unt_sng,"%d-%d",&year,&month) == 2)
+  {
+    /* udunits requires  this prefix that it can recognize a raw-datetime string */  
+    strcpy(lcl_unt_sng,"s@");
+    strcat(lcl_unt_sng,val_unt_sng);
+  }
+  else
+  {
+    /* Regular conversion of fl_unt_sng of form <double_value units>, e.g., '10 inches', '100 ft'  '10 days since 1970-01-01' */
+    char *ptr=(char*)NULL;
+        
+    dval=strtod(val_unt_sng, &ptr);  
+        
+    if(ptr==val_unt_sng || strlen(++ptr)<1)
+    {
+      (void)fprintf(stderr, "%s: INFO %s() reports input string must be of the form \"value unit\" got the string \"%s\"\n",nco_prg_nm_get(),fnc_nm,val_unt_sng);
+      nco_exit(EXIT_FAILURE);           
+    }
+    strcpy(lcl_unt_sng,ptr); 
+  }
+
+  /* use custom time functions if irregular calendar */
+  if(is_date && (lmt_cln==cln_360 || lmt_cln==cln_365) )
+    rcd=nco_cln_clc_tm( lcl_unt_sng, fl_bs_sng,lmt_cln,&dval, (var_sct*)NULL);  
+  else
+    rcd=nco_cln_clc_dbl_dff(lcl_unt_sng, fl_bs_sng,&dval);     
+	       	     
+
+  /* only copy over if successfull */ 
+  if(rcd==NCO_NOERR)
+     *og_val=dval;
+    
+  return rcd;        
+}
+
+/* This function is only called if the target units in fl_bs_sng of the form "value unit since date-stamp" 
+   and the calendar type is cln_360 or cln_365.
+   either "var" is NULL and there is a single value to process *og_val 
+   or var is initialized and  og_val is NULL  */
+int /* [rcd] Successful conversion returns NCO_NOERR */
+nco_cln_clc_tm /* [fnc] Difference between two coordinate units */
+(const char *fl_unt_sng, /* I [ptr] Units attribute string from disk */
+ const char *fl_bs_sng, /* I [ptr] Units attribute string from disk */
+ nco_cln_typ lmt_cln, /* [enum] Calendar type of coordinate variable */ 
+ double *og_val, /* I/O [ptr] */
+ var_sct *var){  /* I/O [ptr] */  
+  int rcd;
+  int year;
+  int month;
+  char *lcl_unt_sng;
+  /* 20141230 figure out better length */
+  char tmp_sng[100];
+  double crr_val;
+  double scl_val;
+
+  tm_typ unt_tm_typ; /* enum for units type in fl_unt_sng */  
+  tm_typ bs_tm_typ; /* enum for units type in fl_bs_sng */
+
+  tm_cln_sct unt_cln_sct;
+  tm_cln_sct bs_cln_sct;
+  
+  if(nco_dbg_lvl_get() >= nco_dbg_scl) 
+     (void)fprintf(stderr,"%s: nco_cln_clc_tm() reports unt_sng=%s bs_sng=%s\n",nco_prg_nm_get(),fl_unt_sng,fl_bs_sng);
+
+  /* blow out if bad cln type */
+  if(lmt_cln != cln_360 &&  lmt_cln != cln_365)
+  {
+    (void)fprintf(stderr,"%s: nco_cln_clc_tm() has been called with wrong calander types - only cln_365 and cln_360 allowed\n",nco_prg_nm_get());
+    nco_exit(EXIT_FAILURE); 
+  }       
+  
+
+  /* Obtain units type from fl_bs_sng */
+  if(sscanf(fl_bs_sng,"%s",tmp_sng) != 1) return NCO_ERR;
+    bs_tm_typ=nco_cln_get_tm_typ(tmp_sng);  
+
+  /* Obtain units type from fl_bs_sng */
+  if(sscanf(fl_unt_sng,"%s",tmp_sng) != 1) return NCO_ERR;
+    unt_tm_typ=nco_cln_get_tm_typ(tmp_sng);  
+
+  
+  /* Assume non-standard calendar */ 
+  if(nco_cln_prs_tm(fl_unt_sng,&unt_cln_sct) == NCO_ERR) return NCO_ERR;
+  if(nco_cln_prs_tm(fl_bs_sng,&bs_cln_sct) == NCO_ERR) return NCO_ERR;
+  
+  unt_cln_sct.sc_typ=bs_tm_typ;
+  bs_cln_sct.sc_typ=bs_tm_typ;
+  
+  unt_cln_sct.sc_cln=lmt_cln;
+  bs_cln_sct.sc_cln=lmt_cln; 
+  (void)nco_cln_pop_val(&unt_cln_sct);
+  (void)nco_cln_pop_val(&bs_cln_sct);
+  
+  /* get offset */
+  crr_val= (unt_cln_sct.value-bs_cln_sct.value) /  nco_cln_val_tm_typ(lmt_cln,bs_tm_typ);                 
+
+  /* scale factor */
+  if( unt_tm_typ== bs_tm_typ)
+    scl_val=1.0;
+  else
+    scl_val=nco_cln_val_tm_typ(lmt_cln,unt_tm_typ) / nco_cln_val_tm_typ(lmt_cln,bs_tm_typ);                   ;                    
+  
+  if(og_val)
+  {   
+    *og_val=*og_val*scl_val+crr_val;     
+
+  }
+  else if(var)
+  {
+    size_t sz;
+    size_t idx;
+    ptr_unn op1;    
+    
+    sz=var->sz;  
+    op1=var->val;
+    (void)cast_void_nctype(var->type,&op1);
+
+    if(var->type == NC_DOUBLE)
+    {
+      double *dp;
+      dp=op1.dp;   
+
+      if(var->has_mss_val)
+      {  
+	double mss_dbl=var->mss_val.dp[0]; 
+	for(idx=0; idx<sz; idx++)
+	  if( dp[idx] != mss_dbl) 
+	    dp[idx]= dp[idx]*scl_val+crr_val; 
+      } 
+      else
+	for(idx=0; idx<sz; idx++) 
+          dp[idx]= dp[idx]*scl_val+crr_val; 
+    }
+
+    if(var->type == NC_FLOAT)
+    {
+      float *fp;
+      fp=op1.fp;   
+
+      if(var->has_mss_val)
+      {  
+	float mss_ft=var->mss_val.fp[0]; 
+	for(idx=0; idx<sz; idx++)
+	   if( fp[idx] != mss_ft) fp[idx]=fp[idx]*scl_val+crr_val;                      
+      } 
+      else
+	for(idx=0; idx<sz; idx++)
+	  fp[idx]=fp[idx]*scl_val+crr_val;                      
+    }
+
+   (void)cast_nctype_void(var->type,&op1);
+
+  }
+  lcl_unt_sng=(char *)nco_free(lcl_unt_sng);
+  
+  return NCO_NOERR;
+} /* end nco_cln_clc_tm() */
+
+int /* [rcd] Successful conversion returns NCO_NOERR */
+nco_cln_prs_tm /* UDUnits2 Extract time stamp from parsed UDUnits string */
+(const char *unt_sng, /* I [ptr] units attribute string */
+ tm_cln_sct *tm_in) /* O [sct] Time structure to be populated */
+{
+  const char fnc_nm[]="nco_cln_prs_tm()"; /* [sng] Function name */
+
+  /* 20141230: fxm figure out a better length */
+  char bfr[200];
+
+  char *dt_sng;
+
+  int ut_rcd; /* [enm] UDUnits2 status */
+
+  ut_system *ut_sys;
+  ut_unit *ut_sct_in; /* UDUnits structure, input units */
+
+  /* When empty, ut_read_xml() uses environment variable UDUNITS2_XML_PATH, if any
+     Otherwise it uses default initial location hardcoded when library was built */
+  if(nco_dbg_lvl_get() >= nco_dbg_vrb) ut_set_error_message_handler(ut_write_to_stderr); else ut_set_error_message_handler(ut_ignore);
+  ut_sys=ut_read_xml(NULL);
+  if(ut_sys == NULL){
+    (void)fprintf(stdout,"%s: %s failed to initialize UDUnits2 library\n",nco_prg_nm_get(),fnc_nm);
+    return NCO_ERR; /* Failure */
+  } /* end if err */ 
+
+  /* Units string to convert from */
+  ut_sct_in=ut_parse(ut_sys,unt_sng,UT_ASCII); 
+  if(ut_sct_in == NULL){ /* Problem with 'units' attribute */
+    ut_rcd=ut_get_status(); /* [enm] UDUnits2 status */
+    if(ut_rcd == UT_BAD_ARG) (void)fprintf(stderr,"ERROR: empty units attribute string\n");
+    if(ut_rcd == UT_SYNTAX)  (void)fprintf(stderr,"ERROR: units attribute \"%s\" has a syntax error\n",unt_sng);
+    if(ut_rcd == UT_UNKNOWN) (void)fprintf(stderr,"ERROR: units attribute \"%s\" is not listed in UDUnits2 SI system database\n",unt_sng);
+
+    return NCO_ERR; /* Failure */
+  } /* endif coordinate on disk has no units attribute */
+
+  /* Print timestamp to buffer in standard, dependable format */
+  ut_format(ut_sct_in,bfr,sizeof(bfr),UT_ASCII|UT_NAMES);
+
+  /* Extract parsed time units from print string (kludgy)
+     20141230 change to using ut_decode_time() instead? */
+  dt_sng=strstr(bfr,"since");  
+  sscanf(dt_sng,"%*s %d-%d-%d %d:%d:%f",&tm_in->year,&tm_in->month,&tm_in->day,&tm_in->hour,&tm_in->min,&tm_in->sec);
+
+  ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
+  ut_free(ut_sct_in);
+
+  return NCO_NOERR;
+} /* end UDUnits2 nco_cln_prs_tm() */
+
 int /* [rcd] Return code */
 nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
 (const ptr_unn val, /* I [sct] Value to rebase */
@@ -721,8 +837,6 @@ nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
      cdRel2Iso() from CDMS by Bob Drach, LLNL
      cdParseRelunits() from CDMS by Bob Drach, LLNL */
 
-#ifdef HAVE_UDUNITS2_H
-
   const char fnc_nm[]="nco_cln_sng_rbs()"; /* [sng] Function name */
   
   double val_dbl; /* [day] Calendar offset converted to double */
@@ -773,7 +887,6 @@ nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
   ut_free(ut_sct_in);
   ut_free(ut_sct_out);
   ut_free_system(ut_sys); /* Free memory taken by UDUnits library */
-#endif /* !HAVE_UDUNITS2 */
 
   lgb_sng[0]='\0'; /* CEWI */
 
@@ -781,3 +894,7 @@ nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
 
 } /* end nco_cln_sng_rbs() */
 
+# endif /* HAVE_UDUNITS2_H */
+#endif /* ENABLE_UDUNITS */
+/* End UDUnits-related routines*/
+ 
