@@ -83,22 +83,11 @@ nco_newdate /* [fnc] Compute date a specified number of days from input date */
 (const nco_int date, /* I [YYMMDD] Date */
  const nco_int day_srt); /* I [day] Days ahead of input date */
 
-int               /* [flg] NCO_NOERR or NCO_ERR */ 
-nco_cln_clc_dff( /* [fnc] difference between two co-ordinate units */
-const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
-const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
-double crr_val, /* I [dbl] input units value */
-double *rgn_val); /* O difference between two units string */
-
-int /* [flg] NCO_NOERR or NCO_ERR */
-nco_cln_prs_tm( /* Extract time stamp from a parsed udunits string */
-const char *unt_sng, /* I [ptr] units attribute string */  
-tm_cln_sct *tm_in); /*  O [sct] struct to be populated */
-
 tm_typ /* [enum] Units type */
 nco_cln_get_tm_typ( /* returns time unit type or tm_void if not found */
 const char *ud_sng); /* I [ptr] units string */
 
+
 nco_cln_typ /* [enum] Calendar type */    
 nco_cln_get_cln_typ( /* [fnc] Calendar type or cln_nil if not found */
 const char *ud_sng); /* I [ptr] units string */
@@ -112,30 +101,76 @@ void
 nco_cln_pop_val( /* [fnc] Calculate value in cln_sct */ 
 tm_cln_sct *cln_sct);/* I/O [ptr] Calendar structure */
 
-double /* O [dbl] Relative time */
-nco_cln_rel_val( /* [fnc] */
-double offset, /* I [dbl] time in base units */
+double /* O [dbl] time in (base) seconds of tm_typ */
+nco_cln_val_tm_typ( /* [fnc] */
 nco_cln_typ lmt_cln, /* I [enum] Calendar type */
 tm_typ bs_tm_typ); /* I [enum] Time units */
 
-int /* O [flg] NCO_NOERR or NCO_ERR */ 
-nco_cln_clc_tm( /* [fnc] Difference between two time coordinate units */
-const char *fl_unt_sng, /* I [ptr] user units attribute string */
-const char *fl_bs_sng, /* I [ptr] units attribute string from disk  */     
-nco_cln_typ lmt_cln, /* [enm] Calendar type of coordinate var */ 
-double *rgn_val); /* O [ptr] time diff in units based on fl_bs_sng */ 
-
-int /* O [flg] NCO_NOERR or NCO_ERR */ 
-nco_cln_clc_org( /* [fnc] Difference between two generic coordinate units */      
-const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
-const char *fl_bs_sng, /* I [ptr] units attribute string from disk */
-nco_cln_typ lmt_cln, /* I [enum] Calendar type of coordinate var */ 
-double *og_val); /* O [ptr] */
 
 int /* O [flg] String is calendar date */
 nco_cln_chk_tm /* [fnc] Is string a UDUnits-compatible calendar format, e.g., "PERIOD since REFERENCE_DATE" */
 (const char *unit_sng); /* I [sng] Units string */
 
+#ifndef ENABLE_UDUNITS
+
+int    /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_var_dff( /* [fnc] difference between two co-ordinate units */
+const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
+double *dval,           /* I/O [dbl] var values modified */
+var_sct *var);           /* I/O [var_sct] var values modified */
+
+int   /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_org(   /* [fnc] difference between two co-ordinate units */
+const char *val_unt_sng, /* I [ptr] input value and  units in the same string */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
+double *og_val);         /* O [dbl] output value */
+
+#endif
+
+
+#ifdef ENABLE_UDUNITS
+#ifdef HAVE_UDUNITS2_H
+
+cv_converter*   /* UDUnits converter */
+nco_cln_cnv_mk  /* [fnc] UDUnits2 create a custom converter  */
+(const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+ const char *fl_bs_sng);/* I [ptr] units attribute string from disk */
+
+
+int    /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_var_dff( /* [fnc] difference between two co-ordinate units */
+const char *fl_unt_sng, /* I [ptr] units attribute string from disk */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
+double *dval,           /* I/O [dbl] var values modified */
+var_sct *var);           /* I/O [var_sct] var values modified */
+
+int   /* [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_dbl_org(   /* [fnc] difference between two co-ordinate units */
+const char *val_unt_sng, /* I [ptr] input value and  units in the same string */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk */
+nco_cln_typ lmt_cln,    /* I [enum] Calendar type of coordinate var */ 
+double *og_val);         /* O [dbl] output value */
+
+
+int /* O [flg] NCO_NOERR or NCO_ERR */ 
+nco_cln_clc_tm( /* [fnc] Difference between two time coordinate units */
+const char *fl_unt_sng, /* I [ptr] user units attribute string */
+const char *fl_bs_sng,  /* I [ptr] units attribute string from disk  */     
+nco_cln_typ lmt_cln,  /* [enm] Calendar type of coordinate var */ 
+double *rgn_val, /* I/O [ptr] time diff in units based on fl_bs_sng */ 
+var_sct *var);   /* I/O [ptr]  */ 
+
+
+int /* [flg] NCO_NOERR or NCO_ERR */
+nco_cln_prs_tm( /* Extract time stamp from a parsed udunits string */
+const char *unt_sng, /* I [ptr] units attribute string */  
+tm_cln_sct *tm_in); /*  O [sct] struct to be populated */
+
+
 int /* [rcd] Return code */
 nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
 (const ptr_unn val, /* I [sct] Value to rebase */
@@ -144,6 +179,12 @@ nco_cln_sng_rbs /* [fnc] Rebase calendar string for legibility */
  const char *unit_sng, /* I [sng] Units string */
  char *lgb_sng); /* O [sng] Legible version of input string */
 
+
+
+#endif /* !HAVE_UDUNITS2_H */
+#endif /* !ENABLE_UDUNITS */
+
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
