@@ -234,6 +234,7 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
  const int dmn_nbr_rdc,              /* I [sct] Number of dimensions to reduce variable over */
  const int nco_op_typ,               /* I [enm] Operation type, default is average */
  gpe_sct *gpe,                       /* I [sng] Group Path Editing (GPE) structure */
+ const clm_bnd_sct * const cb,       /* I [sct] Climatology bounds structure */
  const trv_tbl_sct * const trv_tbl)  /* I [sct] Traversal table */
 {
   /* Purpose: Add/modify CF cell_methods attribute
@@ -277,6 +278,7 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
   char *att_val_cpy; /* [sng] Copy of attribute */
   char *grp_out_fll=NULL; /* [sng] Group name */
   char *sbs_ptr; /* [sng] Pointer to substring */
+  char *cll_mth_clm; /* [sng] Cell methods for climatology */
   
   int *dmn_mch; /* [idx] Indices of dimensions reduced in this variable */
 
@@ -309,6 +311,11 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
   /* Allocate space for maximum number of matching dimensions */
   dmn_mch=(int *)nco_calloc(dmn_nbr_rdc,sizeof(int));
 
+  if(cb){
+    if(cb->bnd2clm || cb->clm2clm) cll_mth_clm=strdup("time: mean within years time: mean over years");
+    if(cb->clm2bnd) cll_mth_clm=strdup("time: mean");
+  } /* !cb */
+
   /* Process all variables */
   for(var_idx=0;var_idx<var_nbr;var_idx++){ 
 
@@ -334,6 +341,23 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
     dmn_nbr_mch=0;
     flg_dpl=False;
 
+    if(cb){
+      /* Does variable use time coordinate? */
+      for(dmn_idx_var=0;dmn_idx_var<var_trv->nbr_dmn;dmn_idx_var++)
+	if(!strcmp(var_trv->var_dmn[dmn_idx_var].dmn_nm,cb->tm_crd_nm)) break;
+      if(dmn_idx_var < var_trv->nbr_dmn){
+	/* Stamp with appropriate cell_methods temporal attribute */
+	att_val=strdup(cll_mth_clm);
+	aed.sz=strlen(att_val);
+	aed.type=NC_CHAR;
+	aed.val.cp=att_val;
+	aed.mode=aed_overwrite;
+	(void)nco_aed_prc(grp_out_id,var_out_id,aed);
+	if(att_val) att_val=(char *)nco_free(att_val);
+	continue;
+      } /* !dmn_idx_var */
+    } /* !cb */
+
     /* cell_methods format: blank-separated phrases of form "dmn1[, dmn2[...]]: op_typ", e.g., "lat, lon: mean" */ 
     for(dmn_idx_var=0;dmn_idx_var<var_trv->nbr_dmn;dmn_idx_var++){
       for(dmn_idx_rdc=0;dmn_idx_rdc<dmn_nbr_rdc;dmn_idx_rdc++){
@@ -396,7 +420,7 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
     strcpy(aed.att_nm,"cell_method");
     rcd=nco_inq_att_flg(grp_out_id,var_out_id,aed.att_nm,&att_typ,&att_lng);
     if(rcd == NC_NOERR){
-      if(FIRST_WARNING) (void)fprintf(stderr,"%s: WARNING: Variable \"%s\" uses the non-standard attribute name \"cell_method\" instead of \"cell_methods\", the correct attribute name. The CAM3 model (and others?) have this problem. Expect \"double attributes\" in output. This message is printed only once per invocation, although the problem likely occurs in more variables.\n",nco_prg_nm_get(),aed.var_nm);
+      if(FIRST_WARNING) (void)fprintf(stderr,"%s: WARNING: Variable \"%s\" uses the non-standard attribute name \"cell_method\" instead of \"cell_methods\", the correct attribute name. The CAM3 model (and others?) have this problem. Expect \"double attributes\" in output. This message is printed only once per invocation, although the problem likely occurs in multiple variables.\n",nco_prg_nm_get(),aed.var_nm);
       FIRST_WARNING=False;
     } /* endif attribute exists */
 
@@ -407,9 +431,15 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
       if(att_typ == NC_STRING) (void)fprintf(stderr,"%s: WARNING %s reports existing cell_methods attribute for variable %s is type NC_STRING. Unpredictable results...\n",nco_prg_nm_get(),fnc_nm,aed.var_nm);
       if(att_typ != NC_STRING && att_typ != NC_CHAR) (void)fprintf(stderr,"%s: WARNING %s reports existing cell_methods attribute for variable %s is type %s. Unpredictable results...\n",nco_prg_nm_get(),fnc_nm,aed.var_nm,nco_typ_sng(att_typ));
 
-      /* 20150625: Often climatologies are multiply-averaged over time
+      /* Often climatologies are multiply-averaged over time
+	 NCO's treatment of this has changed with time
+	 pre-20140131: 
+	 NCO has no special treatment of cell_methods
+	 20140131: 
+	 First NCO implementation (ncra, ncea, ncwa) of cell_methods with 
+	 20150625: 
 	 For example, climate model output is often archived as monthly means in each gridcell
-	 The cell_methods attribute of these monthly data begin as "time: mean" (i.e., monthly mean).
+	 cell_methods attributes of these monthly data begin as "time: mean" (i.e., monthly mean).
 	 We then create a climatology by a sequence of one or two more temporal-averaging steps
 	 The one-step method puts all the months in the hopper and averages those
 	 Variables in the resultiing file may have cell_methods = "time: mean time: mean"
@@ -417,7 +447,17 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
 	 Then it averages those four seasons into the climatological annual mean
 	 Variables in the resultiing file may have cell_methods = "time: mean time: mean time: mean"
 	 To avoid this redundancy, we check that the new cell_method does not duplicate the old 
-	 If it would, then skip adding the new */
+	 If it would, then skip adding the new
+	 20160418: 
+	 Treatment of multiply-time-averaged quantities requires climatology bounds attribute
+	 One-step methods (e.g., monthly mean) should have time-bounds attribute
+	 cell_methods = "time: mean"
+	 Two-step methods (e.g., climatological March) should have climatology-bounds attribute
+	 cell_methods = "time: mean within years time: mean over years"
+	 Three-step methods (e.g., climatological MAM) should have climatology-bounds attribute
+	 cell_methods = "time: mean within years time: mean over years"
+	 Four-step methods (e.g., climatological ANN) should have time-bounds attribute
+	 cell_methods = "time: mean" */
       ptr_unn val_old; /* [sng] Old cell_methods attribute */
       val_old.vp=(void *)nco_malloc((att_lng+1L)*sizeof(char));
       (void)nco_get_att(grp_out_id,var_out_id,aed.att_nm,val_old.vp,NC_CHAR);
@@ -436,9 +476,9 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
       aed.val.cp[1]='\0';
       (void)strncat(aed.val.cp,att_val_cpy,aed.sz-1L);
       if(att_val_cpy) att_val_cpy=(char *)nco_free(att_val_cpy);
-    }else{
+    }else{ /* !cell_methods attribute already exists */
       aed.mode=aed_create;
-    } /* endif attribute exists */
+    } /* !cell_methods attribute already exists */
 
     /* Edit attribute */
     if(!flg_dpl) (void)nco_aed_prc(grp_out_id,var_out_id,aed);
@@ -481,7 +521,7 @@ nco_cnv_cf_cll_mth_add               /* [fnc] Add cell_methods attributes */
 		dmn_sng_lng=strlen(dmn_rdc[dmn_idx_rdc]->nm);
 		sbs_sng_lng=(size_t)(sbs_ptr-att_val);
 		aed.mode=aed_overwrite;
-		/* If dimension to excise is trailed by a space, also remove the space, i.e., count it as part of dimension string
+		/* Remove whitespace immediately following excised dimension, i.e., count it as part of dimension string
 		   True for all dimensions except final dimension (trailed by a NUL, not a space) */
 		if(sbs_ptr[dmn_sng_lng] == ' ') dmn_sng_lng++;
 		aed.sz=att_lng-dmn_sng_lng;
