@@ -285,61 +285,62 @@ nco_msa_clc_idx
     crr_idx=nco_msa_min_idx(indices,mnm,size);
 
     crr_slb=-1;
-    for(sz_idx=0;sz_idx<size;sz_idx++)
+    for(sz_idx=0;sz_idx<size;sz_idx++){
       if(mnm[sz_idx]){crr_slb=sz_idx;break;}
-
-      if(crr_slb == -1){
-        if(lmt->srt == -1L){
-          rcd=False;
-          goto cln_and_xit;
-        }else break;
-      } /* endif */
-
-      if(mnm[prv_slb]) crr_slb=prv_slb;
-
-      if(lmt->srt > -1L && crr_slb != prv_slb) break;
-
-      if(lmt->cnt > 1L){
-        (lmt->cnt)++;
-        lmt->end=crr_idx;
-      } /* end if */
-
-      if(lmt->cnt == 1L){
-        lmt->cnt=2L;
-        lmt->srd=crr_idx-prv_idx;
-        lmt->end=crr_idx;
-      } /* end if */
-
+    } /* !sz_idx */
+    
+    if(crr_slb == -1){
       if(lmt->srt == -1L){
-        lmt->srt=crr_idx;
-        lmt->cnt=1L;
-        lmt->end=crr_idx;
-        lmt->srd=1L;
-      } /* end if */
-
-      for(sz_idx=0;sz_idx<size;sz_idx++){
-        if(mnm[sz_idx]){
-          indices[sz_idx]+=lmt_a->lmt_dmn[sz_idx]->srd;
-          if(indices[sz_idx] > lmt_a->lmt_dmn[sz_idx]->end) indices[sz_idx]=-1L;
-        }
-      } /* end loop over sz_idx */
-      prv_idx=crr_idx;
-      prv_slb=crr_slb;
+	rcd=False;
+	goto cln_and_xit;
+      }else break;
+    } /* endif */
+    
+    if(mnm[prv_slb]) crr_slb=prv_slb;
+    
+    if(lmt->srt > -1L && crr_slb != prv_slb) break;
+    
+    if(lmt->cnt > 1L){
+      (lmt->cnt)++;
+      lmt->end=crr_idx;
+    } /* end if */
+    
+    if(lmt->cnt == 1L){
+      lmt->cnt=2L;
+      lmt->srd=crr_idx-prv_idx;
+      lmt->end=crr_idx;
+    } /* end if */
+    
+    if(lmt->srt == -1L){
+      lmt->srt=crr_idx;
+      lmt->cnt=1L;
+      lmt->end=crr_idx;
+      lmt->srd=1L;
+    } /* end if */
+    
+    for(sz_idx=0;sz_idx<size;sz_idx++){
+      if(mnm[sz_idx]){
+	indices[sz_idx]+=lmt_a->lmt_dmn[sz_idx]->srd;
+	if(indices[sz_idx] > lmt_a->lmt_dmn[sz_idx]->end) indices[sz_idx]=-1L;
+      }
+    } /* end loop over sz_idx */
+    prv_idx=crr_idx;
+    prv_slb=crr_slb;
   } /* end while */
-
+  
   *slb=prv_slb;
-
+  
   /* Normalize slab */
   if(NORMALIZE){
     lmt->srt=(lmt->srt-lmt_a->lmt_dmn[*slb]->srt)/(lmt_a->lmt_dmn[*slb]->srd);
     lmt->end=(lmt->end-lmt_a->lmt_dmn[*slb]->srt)/(lmt_a->lmt_dmn[*slb]->srd);
     lmt->srd=1L;
   } /* end if */
-
+  
   rcd=True;
-
+  
   /* Jump here if only one string */
-cln_and_xit:
+ cln_and_xit:
   mnm=(nco_bool *)nco_free(mnm);
 
   return rcd;
@@ -439,7 +440,9 @@ nco_msa_clc_cnt
 
   /* If slabs remain in user-specified order */
   if(lmt_lst->MSA_USR_RDR){
-    for(idx=0;idx<size;idx++) cnt+=lmt_lst->lmt_dmn[idx]->cnt;
+    for(idx=0;idx<size;idx++){
+      cnt+=lmt_lst->lmt_dmn[idx]->cnt;
+     }
     lmt_lst->dmn_cnt=cnt;
   }else{
     indices=(long *)nco_malloc(size*sizeof(long));
@@ -848,7 +851,7 @@ nco_msa_wrp_splt_trv   /* [fnc] Split wrapped dimensions (GTT version) */
 
     if(dmn_trv->lmt_msa.lmt_dmn[idx]->srt > dmn_trv->lmt_msa.lmt_dmn[idx]->end){
 
-      if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"%s: INFO %s dimension <%s> has wrapped limits (%li->%li):\n",nco_prg_nm_get(),fnc_nm,dmn_trv->nm_fll,dmn_trv->lmt_msa.lmt_dmn[idx]->srt,dmn_trv->lmt_msa.lmt_dmn[idx]->end);
+      if(nco_dbg_lvl_get() == nco_dbg_dev) (void)fprintf(stdout,"%s: INFO %s dimension <%s> has wrapped limits (%li->%li):\n",nco_prg_nm_get(),fnc_nm,dmn_trv->nm_fll,dmn_trv->lmt_msa.lmt_dmn[idx]->srt,dmn_trv->lmt_msa.lmt_dmn[idx]->end);
 
       lmt_wrp=(lmt_sct *)nco_malloc(2*sizeof(lmt_sct));
 
@@ -891,7 +894,7 @@ nco_msa_wrp_splt_trv   /* [fnc] Split wrapped dimensions (GTT version) */
         lmt_wrp[1].srd=srd;
       } /* end else */
 
-      if(nco_dbg_lvl_get() == nco_dbg_old){
+      if(nco_dbg_lvl_get() == nco_dbg_dev){
         (void)fprintf(stdout,"%s: INFO %s wrapped limits for <%s> found: ",nco_prg_nm_get(),fnc_nm,dmn_trv->nm_fll);
         (void)fprintf(stdout,"%d:\n",dmn_trv->lmt_msa.lmt_dmn_nbr);
       }
@@ -923,8 +926,10 @@ nco_msa_wrp_splt_trv   /* [fnc] Split wrapped dimensions (GTT version) */
       /* Update current index of dimension limits for this table dimension  */
       dmn_trv->lmt_msa.lmt_crr++;
 
-      if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"%s: INFO %s dimension <%s> new limits inserted (%li->%li) - (%li->%li):\n",nco_prg_nm_get(),fnc_nm,dmn_trv->nm_fll,dmn_trv->lmt_msa.lmt_dmn[idx]->srt,dmn_trv->lmt_msa.lmt_dmn[idx]->end,dmn_trv->lmt_msa.lmt_dmn[lmt_new_idx]->srt,dmn_trv->lmt_msa.lmt_dmn[lmt_new_idx]->end);
-
+      if (nco_dbg_lvl_get() == nco_dbg_dev){
+        (void)fprintf(stdout, "%s: INFO %s dimension <%s> new limits inserted (%li->%li) - (%li->%li):\n", 
+          nco_prg_nm_get(), fnc_nm, dmn_trv->nm_fll, dmn_trv->lmt_msa.lmt_dmn[idx]->srt, dmn_trv->lmt_msa.lmt_dmn[idx]->end, dmn_trv->lmt_msa.lmt_dmn[lmt_new_idx]->srt, dmn_trv->lmt_msa.lmt_dmn[lmt_new_idx]->end);
+      }
     } /* endif srt > end */
   } /* end loop over size */
 
@@ -954,7 +959,9 @@ nco_msa_clc_cnt_trv     /* [fnc] Calculate size of  multiple hyperslab (GTT vers
 
   /* If slabs remain in user-specified order */
   if(dmn_trv->lmt_msa.MSA_USR_RDR){
-    for(idx=0;idx<size;idx++) cnt+=dmn_trv->lmt_msa.lmt_dmn[idx]->cnt;
+    for(idx=0;idx<size;idx++){
+      cnt+=dmn_trv->lmt_msa.lmt_dmn[idx]->cnt;
+     }
     dmn_trv->lmt_msa.dmn_cnt=cnt;
   }else{
     indices=(long *)nco_malloc(size*sizeof(long));
@@ -1172,8 +1179,8 @@ nco_msa_wrp_splt_cpy    /* [fnc] Split wrapped dimensions (make deep copy of new
       /* Current number of dimension limits for this table dimension  */
       int lmt_dmn_nbr=lmt_lst->lmt_dmn_nbr;
 
-      /* Index of new limit  */
-      int lmt_new_idx=idx+1;
+      /* Index of new limit  (insert at last index) */
+      int lmt_new_idx=lmt_lst->lmt_crr;
 
       /* Make space for 1 more limit  */
       lmt_lst->lmt_dmn=(lmt_sct **)nco_realloc(lmt_lst->lmt_dmn,(lmt_dmn_nbr+1)*sizeof(lmt_sct *));
@@ -1181,7 +1188,7 @@ nco_msa_wrp_splt_cpy    /* [fnc] Split wrapped dimensions (make deep copy of new
       /* Alloc the extra limit  */
       lmt_lst->lmt_dmn[lmt_new_idx]=(lmt_sct *)nco_malloc(sizeof(lmt_sct));
 
-      /* Initialize the extra limit */
+      /* Initialize the extra limit (insert at last index) */
       (void)nco_lmt_init(lmt_lst->lmt_dmn[lmt_new_idx]);
 
       /* Insert the limits to table (allocated; idx was already there; lmt_new_idx was alloced here)   */
