@@ -16,7 +16,7 @@
    nco_var_pck(): called just before writing output file, e.g., in main()
    Bookkeeping hassle is keeping flags in var_prc synchronized with flags in var_prc_out
 
-   From netCDF User's Guide:
+   From netCDF Users Guide:
    scale_factor: If present for a variable, the data are to be multiplied by this factor after the data are read by the application that accesses the data
    add_offset: If present for a variable, this number is added to the data after the data are read by the application. If both scale_factor and add_offset attributes are present, the data are first scaled before the offset is added. 
    When scale_factor and add_offset are used for packing, the associated variable (containing the packed data) is typically of type byte or short, whereas the unpacked values are intended to be of type float or double. Attribute's scale_factor and add_offset should both be of type intended for the unpacked data, e.g., float or double.
@@ -1059,6 +1059,7 @@ nco_var_upk /* [fnc] Unpack variable in memory */
   const char fnc_nm[]="nco_var_upk()";
   const char scl_fct_sng[]="scale_factor"; /* [sng] Unidata standard string for scale factor */
   const char add_fst_sng[]="add_offset"; /* [sng] Unidata standard string for add offset */
+  int nco_upk_cnv_typ;
 
   /* Return if variable in memory is not currently packed */
   if(!var->pck_ram) return var;
@@ -1086,7 +1087,8 @@ nco_var_upk /* [fnc] Unpack variable in memory */
      ncpdq -O -C -U --hdf -v ^pck_.? ~/nco/data/in.nc ~/foo.nc # Unpack HDF
      ncpdq -O -C -P --hdf -v ^pck_.? ~/nco/data/in.nc ~/foo.nc # Unpack HDF and re-pack netCDF */
 
-  if(nco_upk_cnv_get() == nco_upk_netCDF){
+  nco_upk_cnv_typ=nco_upk_cnv_get();
+  if(nco_upk_cnv_typ == nco_upk_netCDF){
     /* netCDF unpack definition: unpacked=(scale_factor*packed)+add_offset */
     
     if(var->has_scl_fct){ /* [flg] Valid scale_factor attribute exists */
@@ -1111,8 +1113,8 @@ nco_var_upk /* [fnc] Unpack variable in memory */
       (void)nco_var_scv_add(var->type,var->sz,var->has_mss_val,var->mss_val,var->val,&add_fst_scv);
     } /* endif has_add_fst */
 
-  }else{ /* !netCDF_unpack_convention */
-    /* 20130729: NASA HDF unpack definition: unpacked=scale_factor*(packed-add_offset) */
+  }else if(nco_upk_cnv_typ == nco_upk_HDF_MOD10){ /* !netCDF_unpack_convention */
+    /* 20130729: NASA HDF MODIS MOD10 unpack definition: unpacked=scale_factor*(packed-add_offset) */
 
     if(var->has_add_fst){ /* [flg] Valid add_offset attribute exists */
       scv_sct add_fst_scv;
@@ -1135,7 +1137,37 @@ nco_var_upk /* [fnc] Unpack variable in memory */
       /* Multiply var by scale_factor */
       (void)nco_var_scv_mlt(var->type,var->sz,var->has_mss_val,var->mss_val,var->val,&scl_fct_scv);
     } /* endif has_scl_fct */
-    
+
+  }else if(nco_upk_cnv_typ == nco_upk_HDF_MOD13){ /* !netCDF_unpack_convention */
+    /* 20160501: NASA HDF MODIS MOD13 unpack definition: unpacked=(packed-add_offset)/scale_factor */
+
+    if(var->has_add_fst){ /* [flg] Valid add_offset attribute exists */
+      scv_sct add_fst_scv;
+      var->add_fst.vp=(void *)nco_malloc(nco_typ_lng(var->typ_upk));
+      (void)nco_get_att(var->nc_id,var->id,add_fst_sng,var->add_fst.vp,var->typ_upk);
+      add_fst_scv=ptr_unn_2_scv(var->typ_upk,var->add_fst);
+      /* Convert var to type of scale_factor for expansion */
+      var=nco_var_cnf_typ(add_fst_scv.type,var);
+      /* Subtract add_offset from var */
+      (void)nco_var_scv_sub(var->type,var->sz,var->has_mss_val,var->mss_val,var->val,&add_fst_scv);
+    } /* endif has_add_fst */
+
+    if(var->has_scl_fct){ /* [flg] Valid scale_factor attribute exists */
+      scv_sct scl_fct_scv;
+      var->scl_fct.vp=(void *)nco_malloc(nco_typ_lng(var->typ_upk));
+      (void)nco_get_att(var->nc_id,var->id,scl_fct_sng,var->scl_fct.vp,var->typ_upk);
+      scl_fct_scv=ptr_unn_2_scv(var->typ_upk,var->scl_fct);
+      /* Convert var to type of scale_factor for expansion */
+      var=nco_var_cnf_typ(scl_fct_scv.type,var);
+      /* Divide var by scale_factor */
+      (void)nco_var_scv_dvd(var->type,var->sz,var->has_mss_val,var->mss_val,var->val,&scl_fct_scv);
+    } /* endif has_scl_fct */
+
+  }else{ /* !netCDF_unpack_convention */
+
+    (void)fprintf(stdout,"%s: ERROR %s reports unknown nco_upk_cnv\n",nco_prg_nm_get(),fnc_nm);
+    nco_exit(EXIT_FAILURE);
+
   } /* !netCDF_unpack_convention */
 
   if(var->has_mss_val) var=nco_cnv_mss_val_typ(var,var->type);
