@@ -64,11 +64,9 @@ nco_ppc_ini /* Set PPC based on user specifications */
  const int ppc_arg_nbr, /* I [nbr] Number of PPC specified */
  trv_tbl_sct * const trv_tbl) /* I/O [sct] Traversal table */
 {
-  int ppc_arg_idx; /* [idx] Index over ppc_arg (i.e., separate invocations of "--ppc var1[,var2]=val") */
   int ppc_var_idx; /* [idx] Index over ppc_lst (i.e., all names explicitly specified in all "--ppc var1[,var2]=val" options) */
   int ppc_var_nbr=0;
   kvm_sct *ppc_lst; /* [sct] List of all PPC specifications */
-  kvm_sct kvm;
 
   if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC){
     /* If user did not explicitly set deflate level for this file ... */
@@ -80,31 +78,45 @@ nco_ppc_ini /* Set PPC based on user specifications */
     if(nco_dbg_lvl_get() >= nco_dbg_std) (void)fprintf(stderr,"%s: INFO Requested Precision-Preserving Compression (PPC) on netCDF3 output dataset. Unlike netCDF4, netCDF3 does not support internal compression. To take full advantage of PPC consider writing file as netCDF4 enhanced (e.g., %s -4 ...) or classic (e.g., %s -7 ...). Or consider compressing the netCDF3 file afterwards with, e.g., gzip or bzip2. File must then be uncompressed with, e.g., gunzip or bunzip2 before netCDF readers will recognize it. See http://nco.sf.net/nco.html#ppc for more information on PPC strategies.\n",nco_prg_nm_get(),nco_prg_nm_get(),nco_prg_nm_get());
   } /* endelse */
 
-  ppc_lst=(kvm_sct *)nco_malloc(NC_MAX_VARS*sizeof(kvm_sct));
+  char *sng_fnl=NULL;
 
-  /* Parse PPCs */
-  for(ppc_arg_idx=0;ppc_arg_idx<ppc_arg_nbr;ppc_arg_idx++){
-    if(!strstr(ppc_arg[ppc_arg_idx],"=")){
-      (void)fprintf(stdout,"%s: Invalid --ppc specification: %s. Must contain \"=\" sign.\n",nco_prg_nm_get(),ppc_arg[ppc_arg_idx]);
-      if(ppc_lst) ppc_lst=(kvm_sct *)nco_free(ppc_lst);
-      nco_exit(EXIT_FAILURE);
-    } /* endif */
-    kvm=nco_sng2kvm(ppc_arg[ppc_arg_idx]);
-    /* nco_sng2kvm() converts argument "--ppc one,two=3" into kvm.key="one,two" and kvm.val=3
-       Then nco_lst_prs_2D() converts kvm.key into two items, "one" and "two", with the same value, 3 */
-    if(kvm.key){
-      int var_idx; /* [idx] Index over variables in current PPC argument */
-      int var_nbr; /* [nbr] Number of variables in current PPC argument */
-      char **var_lst;
-      var_lst=nco_lst_prs_2D(kvm.key,",",&var_nbr);
-      for(var_idx=0;var_idx<var_nbr;var_idx++){ /* Expand multi-variable specification */
-        ppc_lst[ppc_var_nbr].key=strdup(var_lst[var_idx]);
-        ppc_lst[ppc_var_nbr].val=strdup(kvm.val);
-        ppc_var_nbr++;
-      } /* end for */
-      var_lst=nco_sng_lst_free(var_lst,var_nbr);
-    } /* end if */
-  } /* end for */
+  /* Join arguments together */
+  sng_fnl=nco_join_sng(ppc_arg, ppc_arg_nbr);
+  ppc_lst=nco_arg_mlt_prs(sng_fnl);
+
+  if(sng_fnl) sng_fnl=(char *)nco_free(sng_fnl);
+
+  /* jm fxm use more descriptive name than i---what does i count? */
+  for(int index=0;(ppc_lst+index)->key;index++){
+      ppc_var_nbr=index;
+  } /* end loop over i */
+  ppc_var_nbr++;
+
+  // ppc_lst=(kvm_sct *)nco_malloc(NC_MAX_VARS*sizeof(kvm_sct));
+
+  // /* Parse PPCs */
+  // for(ppc_arg_idx=0;ppc_arg_idx<ppc_arg_nbr;ppc_arg_idx++){
+  //   if(!strstr(ppc_arg[ppc_arg_idx],"=")){
+  //     (void)fprintf(stdout,"%s: Invalid --ppc specification: %s. Must contain \"=\" sign.\n",nco_prg_nm_get(),ppc_arg[ppc_arg_idx]);
+  //     if(ppc_lst) ppc_lst=(kvm_sct *)nco_free(ppc_lst);
+  //     nco_exit(EXIT_FAILURE);
+  //   } /* endif */
+  //   kvm=nco_sng2kvm(ppc_arg[ppc_arg_idx]);
+  //   /* nco_sng2kvm() converts argument "--ppc one,two=3" into kvm.key="one,two" and kvm.val=3
+  //      Then nco_lst_prs_2D() converts kvm.key into two items, "one" and "two", with the same value, 3 */
+  //   if(kvm.key){
+  //     int var_idx; /* [idx] Index over variables in current PPC argument */
+  //     int var_nbr; /* [nbr] Number of variables in current PPC argument */
+  //     char **var_lst;
+  //     var_lst=nco_lst_prs_2D(kvm.key,",",&var_nbr);
+  //     for(var_idx=0;var_idx<var_nbr;var_idx++){ /* Expand multi-variable specification */
+  //       ppc_lst[ppc_var_nbr].key=strdup(var_lst[var_idx]);
+  //       ppc_lst[ppc_var_nbr].val=strdup(kvm.val);
+  //       ppc_var_nbr++;
+  //     } /* end for */
+  //     var_lst=nco_sng_lst_free(var_lst,var_nbr);
+  //   } /* end if */
+  // } /* end for */
 
   /* PPC "default" specified, set all non-coordinate variables to default first */
   for(ppc_var_idx=0;ppc_var_idx<ppc_var_nbr;ppc_var_idx++){
