@@ -9,6 +9,30 @@
 
 #include "nco_sng_utl.h" /* String utilities */
 
+#ifdef NEED_STRSEP
+/* 20161106 UNIX always provides strsep(), MSVC never does */
+char * /* O [sng] String to separate */
+strsep /* [fnc] Separate strings */
+(char ** const sng_trg, /* I [sng] String to separate */
+ const char * const sng_dlm) /* I [sng] Delimiter */
+{
+  /* Purpose: NCO replacement for strsep() for Windows MSVC
+     http://stackoverflow.com/questions/8512958/is-there-a-windows-variant-of-strsep */
+  char* sng_srt = *sng_trg;
+  char* sng_ptr;
+
+  sng_ptr= (sng_srt != NULL) ? strpbrk(sng_srt,sng_dlm) : NULL;
+
+  if(sng_ptr == NULL){
+    *sng_trg = NULL;
+  }else{
+    *sng_ptr='\0';
+    *sng_trg=sng_ptr+1;
+  } /* endif */
+  return sng_srt;
+} /* !strsep() */
+#endif /* !NEED_STRSEP */
+
 #ifdef NEED_STRCASECMP
 int /* O [enm] [-1,0,1] sng_1 [<,=,>] sng_2 */
 strcasecmp /* [fnc] Lexicographical case-insensitive string comparison */
@@ -292,6 +316,74 @@ nm2sng_cdl /* [fnc] Turn variable/dimension/attribute name into legal CDL */
   return nm_cdl;
 } /* end nm2sng_cdl() */
 
+char * /* O [sng] JSON-compatible name */
+nm2sng_jsn /* [fnc] Turn variable/dimension/attribute name into legal CDL */
+(const char * const nm_sng) /* I [sng] Name to CDL-ize */
+{
+  /* Valid JSON strings can be any selected set of control chars, any non-conrol chars from ASCII and Unicode 
+     Leave unicode for now see Reference: http://www.json.org */   
+ 
+  char *chr_in_ptr; /* [sng] Pointer to current character in input name */
+  char *chr_out_ptr; /* [sng] Pointer to current character in output name */
+  char *nm_jsn; /* [sng] CDL-compatible name */
+  char *nm_cpy; /* [sng] Copy of input */
+
+  int nm_lng; /* [nbr] Length of original name */
+  
+  if(nm_sng == NULL) return NULL;
+
+  /* Otherwise name may contain special character(s)... */
+  nm_lng=strlen(nm_sng);
+  /* Maximum conceivable length of CDL-ized name */
+  chr_out_ptr=nm_jsn=(char *)nco_malloc(4*nm_lng+1L);
+  /* Copy to preserve const-ness */
+  chr_in_ptr=nm_cpy=(char *)strdup(nm_sng);
+  /* NUL-terminate in case input string is empty so will be output string */
+  chr_out_ptr[0]='\0';
+
+  /* Search and replace special characters */
+  while(*chr_in_ptr)
+  {
+    if(iscntrl(*chr_in_ptr))
+    { 
+      switch(*chr_in_ptr)
+      {    
+         case '\b':
+         case '\f':
+         case '\n':
+         case '\r':
+         case '\t': 
+         case '\\': 
+         case '\"': 
+	 /* according to json spec control char  '/' should be escaped bu this is mangles filepaths so leave it out for now */
+         /* case '\/': */
+         case '\0':	
+           *chr_out_ptr++='\\';
+	   *chr_out_ptr++=*chr_in_ptr;
+	   break;
+         default: 
+            /* ignore other control chars */
+      	  break;
+      }
+    }
+    else
+    {
+      *chr_out_ptr++=*chr_in_ptr;
+    }
+    /* Advance character */
+    chr_in_ptr++;
+  }      
+  /* NUL-terminate */
+  *chr_out_ptr='\0';
+
+  /* Free memory */
+  nm_cpy=(char *)nco_free(nm_cpy);
+
+  return nm_jsn;
+} /* end nm2sng_jsn() */
+
+
+
 char * /* O [sng] CDL-compatible name */
 nm2sng_fl /* [fnc] Turn file name into legal string for shell commands */
 (const char * const nm_sng) /* I [sng] Name to sanitize */
@@ -411,7 +503,7 @@ chr2sng_cdl /* [fnc] Translate C language character to printable, visible ASCII
   } /* end switch */
 
   return val_sng;
-} /* end chr2sng_cdl(0 */
+} /* end chr2sng_cdl() */
 
 char * /* O [sng] String containing printable result */
 chr2sng_xml /* [fnc] Translate C language character to printable, visible ASCII bytes */
@@ -441,7 +533,35 @@ chr2sng_xml /* [fnc] Translate C language character to printable, visible ASCII
   } /* end switch */
 
   return val_sng;
-} /* end chr2sng_xml(0 */
+} /* end chr2sng_xml() */
+
+char * /* O [sng] String containing printable result */
+chr2sng_jsn /* [fnc] Translate C language character to printable, visible ASCII bytes */
+(const char chr_val, /* I [chr] Character to process */
+ char * const val_sng) /* I/O [sng] String to stuff printable result into */
+{
+  /* Purpose: Translate character to C-printable, visible ASCII bytes for JSON
+     Reference: http://www.json.org */
+  switch(chr_val){              /* man ascii:Oct   Dec   Hex   Char \X  */
+  case '\b': strcpy(val_sng,"\\b"); break; /* 010   8     08    BS  '\b' Backspace */
+  case '\f': strcpy(val_sng,"\\f"); break; /* 014   12    0C    FF  '\f' Formfeed */
+  case '\n': strcpy(val_sng,"\\n"); break; /* 012   10    0A    LF  '\n' Linefeed */
+  case '\r': strcpy(val_sng,"\\r"); break; /* 015   13    0D    CR  '\r' Carriage return */
+  case '\t': strcpy(val_sng,"\\t"); break; /* 011   9     09    HT  '\t' Horizontal tab */
+  case '\\': strcpy(val_sng,"\\\\"); break; /* 134  92    5C    \   '\\' */
+  case '\"': strcpy(val_sng,"\\\""); break;/* Unsure why or if this works! */
+  /* fxm: According to JSON spec '/' should be escaped but this mangles UNIX filepaths so leave it out for now */
+  /* case '\/': strcpy(val_sng,"\\/"); break; */ /* 057   47    2F    /   '\\' */
+  case '\0':	
+    break;
+  default: 
+    /* json is quite strict about control-chars - only the above are allowed */
+    if(iscntrl(chr_val)) *val_sng=0; else sprintf(val_sng,"%c",chr_val);
+    break;
+  } /* end switch */
+
+  return val_sng;
+} /* end chr2sng_jsn() */
 
 int /* O [nbr] Number of escape sequences translated */
 sng_ascii_trn /* [fnc] Replace C language '\X' escape codes in string with ASCII bytes */
@@ -645,79 +765,3 @@ nco_sng2typ /* [fnc] Convert user-supplied string to netCDF type enum */
 
 } /* end nco_sng2typ() */
 
-kvm_sct /* O [sct] Key-value pair */
-nco_sng2kvm /* [fnc] Parse string into key-value pair */
-(char *sng) /* I [sng] String to parse, including "=" */
-{
-  /* Purpose: Convert string separated by single delimiter into two strings
-     Routine converts argument "--ppc key1,key2,...,keyN=val" into kvm.key="key1,key2,...keyN" and kvm.val=val
-     e.g., routine converts argument "--ppc one,two=3" into kvm.key="one,two" and kvm.val=3 */
-  char *tkn_sng;
-  const char dlm[]="="; /* [sng] Delimiter */
-  int arg_idx=0; /* [nbr] */
-  kvm_sct kvm;
-
-  /* 20160324: Initialize val to NULL so that can handle empty values, e.g., --gaa history="" */
-  kvm.val=NULL;
-  
-  /* NB: Replace strtok() by strsep()? strtok() does not handle consecutive delimiters well
-     20160216: String values that contain delimiter will fail
-     fxm replace all but first delimiter with temporary character until strtok() finishes */
-  tkn_sng=strtok(sng,dlm);
-  while(tkn_sng){
-    arg_idx++;
-    /* fxm: Whitespace-stripping may be unnecessary */
-    nco_sng_strip(tkn_sng);
-    switch(arg_idx){
-    case 1:
-      kvm.key=strdup(tkn_sng);
-      break;
-    case 2:
-      kvm.val=strdup(tkn_sng);
-      break;
-    default:
-      (void)fprintf(stderr,"nco_sng2kvm() cannot get key-value pair from input: %s\n",sng);
-      break;
-    }/* end switch */
-    tkn_sng=strtok(NULL,dlm);
-  }/* end while */
-  return kvm;
-} /* end nco_sng2kvm() */
-
-char * /* O [sng] Stripped-string */
-nco_sng_strip /* [fnc] Strip leading and trailing white space */
-(char *sng) /* I/O [sng] String to strip */
-{
-  /* fxm: seems not working for \n??? */
-  char *srt=sng;
-  while(isspace(*srt)) srt++;
-  size_t end=strlen(srt);
-  if(srt != sng){
-    memmove(sng,srt,end);
-    sng[end]='\0';
-  } /* endif */
-  while(isblank(*(sng+end-1L))) end--;
-  sng[end]='\0';
-  return sng;
-} /* end nco_sng_strip() */
-
-kvm_sct * /* O [sct] Pointer to free'd kvm list */
-nco_kvm_lst_free /* [fnc] Relinquish dynamic memory from list of kvm structures */
-(kvm_sct *kvm, /* I/O [sct] List of kvm structures */
- const int kvm_nbr) /* I [nbr] Number of kvm structures */
-{
-  /* Purpose: Relinquish dynamic memory from list of kvm structures
-     End of list is indicated by NULL in key slot */
-  for(int kvm_idx=0;kvm_idx<kvm_nbr;kvm_idx++){
-    kvm[kvm_idx].key=(char *)nco_free(kvm[kvm_idx].key);
-    kvm[kvm_idx].val=(char *)nco_free(kvm[kvm_idx].val);
-  } /* end for */
-  if(kvm) kvm=(kvm_sct *)nco_free(kvm);
-  return kvm;
-} /* end nco_kvm_lst_free() */
-
-void
-nco_kvm_prn(kvm_sct kvm)
-{
-  if(kvm.key) (void)fprintf(stdout,"%s = %s\n",kvm.key,kvm.val); else return;
-} /* end nco_kvm_prn() */
