@@ -159,11 +159,13 @@ typedef char nco_byte; /* [typ] NC_BYTE */
 # define NCO_BYTE_SNG "char"
 # define NCO_BYTE_IO_SFX text
 # define NCO_GET_ATT_BYTE nc_get_att_text
+# define NCO_GET_VAR_BYTE nc_get_var_text
 # define NCO_GET_VAR1_BYTE nc_get_var1_text
 # define NCO_GET_VARA_BYTE nc_get_vara_text
 # define NCO_GET_VARS_BYTE nc_get_vars_text
 # define NCO_GET_VARM_BYTE nc_get_varm_text
 # define NCO_PUT_ATT_BYTE nc_put_att_text
+# define NCO_PUT_VAR_BYTE nc_put_var_text
 # define NCO_PUT_VAR1_BYTE nc_put_var1_text
 # define NCO_PUT_VARA_BYTE nc_put_vara_text
 # define NCO_PUT_VARS_BYTE nc_put_vars_text
@@ -174,11 +176,13 @@ typedef signed char nco_byte; /* [typ] NC_BYTE */
 # define NCO_BYTE_SNG "signed char"
 # define NCO_BYTE_IO_SFX schar
 # define NCO_GET_ATT_BYTE nc_get_att_schar
+# define NCO_GET_VAR_BYTE nc_get_var_schar
 # define NCO_GET_VAR1_BYTE nc_get_var1_schar
 # define NCO_GET_VARA_BYTE nc_get_vara_schar
 # define NCO_GET_VARS_BYTE nc_get_vars_schar
 # define NCO_GET_VARM_BYTE nc_get_varm_schar
 # define NCO_PUT_ATT_BYTE nc_put_att_schar
+# define NCO_PUT_VAR_BYTE nc_put_var_schar
 # define NCO_PUT_VAR1_BYTE nc_put_var1_schar
 # define NCO_PUT_VARA_BYTE nc_put_vara_schar
 # define NCO_PUT_VARS_BYTE nc_put_vars_schar
@@ -189,11 +193,13 @@ typedef unsigned char nco_byte; /* [typ] NC_BYTE */
 # define NCO_BYTE_SNG "unsigned char"
 # define NCO_BYTE_IO_SFX uchar
 # define NCO_GET_ATT_BYTE nc_get_att_uchar
+# define NCO_GET_VAR_BYTE nc_get_var_uchar
 # define NCO_GET_VAR1_BYTE nc_get_var1_uchar
 # define NCO_GET_VARA_BYTE nc_get_vara_uchar
 # define NCO_GET_VARS_BYTE nc_get_vars_uchar
 # define NCO_GET_VARM_BYTE nc_get_varm_uchar
 # define NCO_PUT_ATT_BYTE nc_put_att_uchar
+# define NCO_PUT_VAR_BYTE nc_put_var_uchar
 # define NCO_PUT_VAR1_BYTE nc_put_var1_uchar
 # define NCO_PUT_VARA_BYTE nc_put_vara_uchar
 # define NCO_PUT_VARS_BYTE nc_put_vars_uchar
@@ -214,11 +220,13 @@ typedef unsigned char nco_ubyte; /* [typ] NC_UBYTE */
 # define NCO_UBYTE_SNG "unsigned char"
 # define NCO_UBYTE_IO_SFX ubyte
 # define NCO_GET_ATT_UBYTE nc_get_att_ubyte
+# define NCO_GET_VAR_UBYTE nc_get_var_ubyte
 # define NCO_GET_VAR1_UBYTE nc_get_var1_ubyte
 # define NCO_GET_VARA_UBYTE nc_get_vara_ubyte
 # define NCO_GET_VARS_UBYTE nc_get_vars_ubyte
 # define NCO_GET_VARM_UBYTE nc_get_varm_ubyte
 # define NCO_PUT_ATT_UBYTE nc_put_att_ubyte
+# define NCO_PUT_VAR_UBYTE nc_put_var_ubyte
 # define NCO_PUT_VAR1_UBYTE nc_put_var1_ubyte
 # define NCO_PUT_VARA_UBYTE nc_put_vara_ubyte
 # define NCO_PUT_VARS_UBYTE nc_put_vars_ubyte
@@ -239,12 +247,14 @@ typedef char nco_char; /* [typ] NC_CHAR */
 # define NCO_CHAR_SNG "char"
 # define NCO_CHAR_IO_SFX text
 # define NCO_GET_ATT_CHAR nc_get_att_text
+# define NCO_GET_VAR_CHAR nc_get_var_text
 # define NCO_GET_VAR1_CHAR nc_get_var1_text
 # define NCO_GET_VARA_CHAR nc_get_vara_text
 # define NCO_GET_VARS_CHAR nc_get_vars_text
 # define NCO_GET_VARM_CHAR nc_get_varm_text
 /* nc_put_att_text() is unique---it uses strlen() to determine argument length */
 # define NCO_PUT_ATT_CHAR(a,b,c,d,e,f) nc_put_att_text(a,b,c,e,f)
+# define NCO_PUT_VAR_CHAR nc_put_var_text
 # define NCO_PUT_VAR1_CHAR nc_put_var1_text
 # define NCO_PUT_VARA_CHAR nc_put_vara_text
 # define NCO_PUT_VARS_CHAR nc_put_vars_text
@@ -255,12 +265,15 @@ typedef signed char nco_char; /* [typ] NC_CHAR */
 # define NCO_CHAR_SNG "signed char"
 # define NCO_CHAR_IO_SFX schar
 # define NCO_GET_ATT_CHAR nc_get_att_schar
+# define NCO_GET_VAR_CHAR nc_get_var_schar
 # define NCO_GET_VAR1_CHAR nc_get_var1_schar
 # define NCO_GET_VARA_CHAR nc_get_vara_schar
 # define NCO_GET_VARS_CHAR nc_get_vars_schar
 # define NCO_GET_VARM_CHAR nc_get_varm_schar
 # define NCO_PUT_ATT_CHAR nc_put_att_schar
+# define NCO_PUT_VAR_CHAR nc_put_var_schar
 # define NCO_PUT_VAR1_CHAR nc_put_var1_schar
+# define NCO_PUT_VARA_CHAR nc_put_vara_schar
 # define NCO_PUT_VARS_CHAR nc_put_vars_schar
 # define NCO_PUT_VARM_CHAR nc_put_varm_schar
 #elif NCO_CHAR == NCO_TYP_UCHAR
@@ -269,11 +282,13 @@ typedef unsigned char nco_char; /* [typ] NC_CHAR */
 # define NCO_CHAR_SNG "unsigned char"
 # define NCO_CHAR_IO_SFX uchar
 # define NCO_GET_ATT_CHAR nc_get_att_uchar
+# define NCO_GET_VAR_CHAR nc_get_var_uchar
 # define NCO_GET_VAR1_CHAR nc_get_var1_uchar
 # define NCO_GET_VARA_CHAR nc_get_vara_uchar
 # define NCO_GET_VARS_CHAR nc_get_vars_uchar
 # define NCO_GET_VARM_CHAR nc_get_varm_uchar
 # define NCO_PUT_ATT_CHAR nc_put_att_uchar
+# define NCO_PUT_VAR_CHAR nc_put_var_uchar
 # define NCO_PUT_VAR1_CHAR nc_put_var1_uchar
 # define NCO_PUT_VARA_CHAR nc_put_vara_uchar
 # define NCO_PUT_VARS_CHAR nc_put_vars_uchar
@@ -294,11 +309,13 @@ typedef unsigned short nco_ushort; /* [typ] NC_USHORT */
 # define NCO_USHORT_SNG "unsigned short"
 # define NCO_USHORT_IO_SFX ushort
 # define NCO_GET_ATT_USHORT nc_get_att_ushort
+# define NCO_GET_VAR_USHORT nc_get_var_ushort
 # define NCO_GET_VAR1_USHORT nc_get_var1_ushort
 # define NCO_GET_VARA_USHORT nc_get_vara_ushort
 # define NCO_GET_VARS_USHORT nc_get_vars_ushort
 # define NCO_GET_VARM_USHORT nc_get_varm_ushort
 # define NCO_PUT_ATT_USHORT nc_put_att_ushort
+# define NCO_PUT_VAR_USHORT nc_put_var_ushort
 # define NCO_PUT_VAR1_USHORT nc_put_var1_ushort
 # define NCO_PUT_VARA_USHORT nc_put_vara_ushort
 # define NCO_PUT_VARS_USHORT nc_put_vars_ushort
@@ -320,11 +337,13 @@ typedef int nco_int; /* [typ] NC_INT */
 # define NCO_INT_SNG "int"
 # define NCO_INT_IO_SFX int
 # define NCO_GET_ATT_INT nc_get_att_int
+# define NCO_GET_VAR_INT nc_get_var_int
 # define NCO_GET_VAR1_INT nc_get_var1_int
 # define NCO_GET_VARA_INT nc_get_vara_int
 # define NCO_GET_VARS_INT nc_get_vars_int
 # define NCO_GET_VARM_INT nc_get_varm_int
 # define NCO_PUT_ATT_INT nc_put_att_int
+# define NCO_PUT_VAR_INT nc_put_var_int
 # define NCO_PUT_VAR1_INT nc_put_var1_int
 # define NCO_PUT_VARA_INT nc_put_vara_int
 # define NCO_PUT_VARS_INT nc_put_vars_int
@@ -335,11 +354,13 @@ typedef long nco_int; /* [typ] NC_INT */
 # define NCO_INT_SNG "long"
 # define NCO_INT_IO_SFX long
 # define NCO_GET_ATT_INT nc_get_att_long
+# define NCO_GET_VAR_INT nc_get_var_long
 # define NCO_GET_VAR1_INT nc_get_var1_long
 # define NCO_GET_VARA_INT nc_get_vara_long
 # define NCO_GET_VARS_INT nc_get_vars_long
 # define NCO_GET_VARM_INT nc_get_varm_long
 # define NCO_PUT_ATT_INT nc_put_att_long
+# define NCO_PUT_VAR_INT nc_put_var_long
 # define NCO_PUT_VAR1_INT nc_put_var1_long
 # define NCO_PUT_VARA_INT nc_put_vara_long
 # define NCO_PUT_VARS_INT nc_put_vars_long
@@ -360,11 +381,13 @@ typedef unsigned int nco_uint; /* [typ] NC_UINT */
 # define NCO_UINT_SNG "unsigned int"
 # define NCO_UINT_IO_SFX uint
 # define NCO_GET_ATT_UINT nc_get_att_uint
+# define NCO_GET_VAR_UINT nc_get_var_uint
 # define NCO_GET_VAR1_UINT nc_get_var1_uint
 # define NCO_GET_VARA_UINT nc_get_vara_uint
 # define NCO_GET_VARS_UINT nc_get_vars_uint
 # define NCO_GET_VARM_UINT nc_get_varm_uint
 # define NCO_PUT_ATT_UINT nc_put_att_uint
+# define NCO_PUT_VAR_UINT nc_put_var_uint
 # define NCO_PUT_VAR1_UINT nc_put_var1_uint
 # define NCO_PUT_VARA_UINT nc_put_vara_uint
 # define NCO_PUT_VARS_UINT nc_put_vars_uint
@@ -385,11 +408,13 @@ typedef long long nco_int64; /* [typ] NC_INT64 */
 # define NCO_INT64_SNG "long long"
 # define NCO_INT64_IO_SFX longlong
 # define NCO_GET_ATT_INT64 nc_get_att_longlong
+# define NCO_GET_VAR_INT64 nc_get_var_longlong
 # define NCO_GET_VAR1_INT64 nc_get_var1_longlong
 # define NCO_GET_VARA_INT64 nc_get_vara_longlong
 # define NCO_GET_VARS_INT64 nc_get_vars_longlong
 # define NCO_GET_VARM_INT64 nc_get_varm_longlong
 # define NCO_PUT_ATT_INT64 nc_put_att_longlong
+# define NCO_PUT_VAR_INT64 nc_put_var_longlong
 # define NCO_PUT_VAR1_INT64 nc_put_var1_longlong
 # define NCO_PUT_VARA_INT64 nc_put_vara_longlong
 # define NCO_PUT_VARS_INT64 nc_put_vars_longlong
@@ -410,11 +435,13 @@ typedef unsigned long long nco_uint64; /* [typ] NC_UINT64 */
 # define NCO_UINT64_SNG "unsigned long long"
 # define NCO_UINT64_IO_SFX ulonglong
 # define NCO_GET_ATT_UINT64 nc_get_att_ulonglong
+# define NCO_GET_VAR_UINT64 nc_get_var_ulonglong
 # define NCO_GET_VAR1_UINT64 nc_get_var1_ulonglong
 # define NCO_GET_VARA_UINT64 nc_get_vara_ulonglong
 # define NCO_GET_VARS_UINT64 nc_get_vars_ulonglong
 # define NCO_GET_VARM_UINT64 nc_get_varm_ulonglong
 # define NCO_PUT_ATT_UINT64 nc_put_att_ulonglong
+# define NCO_PUT_VAR_UINT64 nc_put_var_ulonglong
 # define NCO_PUT_VAR1_UINT64 nc_put_var1_ulonglong
 # define NCO_PUT_VARA_UINT64 nc_put_vara_ulonglong
 # define NCO_PUT_VARS_UINT64 nc_put_vars_ulonglong
@@ -436,12 +463,14 @@ typedef char * nco_string; /* [typ] NC_STRING */
 # define NCO_STRING_SNG "char *"
 # define NCO_STRING_IO_SFX string
 # define NCO_GET_ATT_STRING nc_get_att_string
+# define NCO_GET_VAR_STRING nc_get_var_string
 # define NCO_GET_VAR1_STRING nc_get_var1_string
 # define NCO_GET_VARA_STRING nc_get_vara_string
 # define NCO_GET_VARS_STRING nc_get_vars_string
 # define NCO_GET_VARM_STRING nc_get_varm_string
 /* nc_put_att_string() is unique---it uses strlen() to determine argument length */
 # define NCO_PUT_ATT_STRING(a,b,c,d,e,f) nc_put_att_string(a,b,c,e,f)
+# define NCO_PUT_VAR_STRING nc_put_var_string
 # define NCO_PUT_VAR1_STRING nc_put_var1_string
 # define NCO_PUT_VARA_STRING nc_put_vara_string
 # define NCO_PUT_VARS_STRING nc_put_vars_string
